#!/bin/sh
cd `dirname "$0"`
case $1 in
  p1) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst88 > ../outputs/t1
    exec diff ../outputs/t1 ../golden/t1 >/dev/null 2>&1 ;;
  p2) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst34 > ../outputs/t2
    exec diff ../outputs/t2 ../golden/t2 >/dev/null 2>&1 ;;
  p3) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst16 > ../outputs/t3
    exec diff ../outputs/t3 ../golden/t3 >/dev/null 2>&1 ;;
  p4) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADr.mat > ../outputs/t4
    exec diff ../outputs/t4 ../golden/t4 >/dev/null 2>&1 ;;
  p5) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst6 > ../outputs/t5
    exec diff ../outputs/t5 ../golden/t5 >/dev/null 2>&1 ;;
  p6) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst13 > ../outputs/t6
    exec diff ../outputs/t6 ../golden/t6 >/dev/null 2>&1 ;;
  p7) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst108 > ../outputs/t7
    exec diff ../outputs/t7 ../golden/t7 >/dev/null 2>&1 ;;
  p8) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst17 > ../outputs/t8
    exec diff ../outputs/t8 ../golden/t8 >/dev/null 2>&1 ;;
  p9) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst29 > ../outputs/t9
    exec diff ../outputs/t9 ../golden/t9 >/dev/null 2>&1 ;;
  p10) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst89 > ../outputs/t10
    exec diff ../outputs/t10 ../golden/t10 >/dev/null 2>&1 ;;
  p11) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst8 > ../outputs/t11
    exec diff ../outputs/t11 ../golden/t11 >/dev/null 2>&1 ;;
  p12) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst9 > ../outputs/t12
    exec diff ../outputs/t12 ../golden/t12 >/dev/null 2>&1 ;;
  p13) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst55 > ../outputs/t13
    exec diff ../outputs/t13 ../golden/t13 >/dev/null 2>&1 ;;
  p14) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst76 > ../outputs/t14
    exec diff ../outputs/t14 ../golden/t14 >/dev/null 2>&1 ;;
  p15) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst109 > ../outputs/t15
    exec diff ../outputs/t15 ../golden/t15 >/dev/null 2>&1 ;;
  p16) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst10 > ../outputs/t16
    exec diff ../outputs/t16 ../golden/t16 >/dev/null 2>&1 ;;
  p17) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst15 > ../outputs/t17
    exec diff ../outputs/t17 ../golden/t17 >/dev/null 2>&1 ;;
  p18) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst19 > ../outputs/t18
    exec diff ../outputs/t18 ../golden/t18 >/dev/null 2>&1 ;;
  p19) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst90 > ../outputs/t19
    exec diff ../outputs/t19 ../golden/t19 >/dev/null 2>&1 ;;
  p20) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst20 > ../outputs/t20
    exec diff ../outputs/t20 ../golden/t20 >/dev/null 2>&1 ;;
  p21) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst56 > ../outputs/t21
    exec diff ../outputs/t21 ../golden/t21 >/dev/null 2>&1 ;;
  p22) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst24 > ../outputs/t22
    exec diff ../outputs/t22 ../golden/t22 >/dev/null 2>&1 ;;
  p23) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst3 > ../outputs/t23
    exec diff ../outputs/t23 ../golden/t23 >/dev/null 2>&1 ;;
  p24) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst25 > ../outputs/t24
    exec diff ../outputs/t24 ../golden/t24 >/dev/null 2>&1 ;;
  p25) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst50 > ../outputs/t25
    exec diff ../outputs/t25 ../golden/t25 >/dev/null 2>&1 ;;
  p26) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst87 > ../outputs/t26
    exec diff ../outputs/t26 ../golden/t26 >/dev/null 2>&1 ;;
  p27) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst91 > ../outputs/t27
    exec diff ../outputs/t27 ../golden/t27 >/dev/null 2>&1 ;;
  p28) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst107 > ../outputs/t28
    exec diff ../outputs/t28 ../golden/t28 >/dev/null 2>&1 ;;
  p29) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst27 > ../outputs/t29
    exec diff ../outputs/t29 ../golden/t29 >/dev/null 2>&1 ;;
  p30) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst77 > ../outputs/t30
    exec diff ../outputs/t30 ../golden/t30 >/dev/null 2>&1 ;;
  p31) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst98 > ../outputs/t31
    exec diff ../outputs/t31 ../golden/t31 >/dev/null 2>&1 ;;
  p32) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst18 > ../outputs/t32
    exec diff ../outputs/t32 ../golden/t32 >/dev/null 2>&1 ;;
  p33) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst28 > ../outputs/t33
    exec diff ../outputs/t33 ../golden/t33 >/dev/null 2>&1 ;;
  p34) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst7 > ../outputs/t34
    exec diff ../outputs/t34 ../golden/t34 >/dev/null 2>&1 ;;
  p35) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst30 > ../outputs/t35
    exec diff ../outputs/t35 ../golden/t35 >/dev/null 2>&1 ;;
  p36) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst107 > ../outputs/t36
    exec diff ../outputs/t36 ../golden/t36 >/dev/null 2>&1 ;;
  p37) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst32 > ../outputs/t37
    exec diff ../outputs/t37 ../golden/t37 >/dev/null 2>&1 ;;
  p38) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst33 > ../outputs/t38
    exec diff ../outputs/t38 ../golden/t38 >/dev/null 2>&1 ;;
  p39) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2 > ../outputs/t39
    exec diff ../outputs/t39 ../golden/t39 >/dev/null 2>&1 ;;
  p40) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst5 > ../outputs/t40
    exec diff ../outputs/t40 ../golden/t40 >/dev/null 2>&1 ;;
  p41) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst92 > ../outputs/t41
    exec diff ../outputs/t41 ../golden/t41 >/dev/null 2>&1 ;;
  p42) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst97 > ../outputs/t42
    exec diff ../outputs/t42 ../golden/t42 >/dev/null 2>&1 ;;
  p43) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst31 > ../outputs/t43
    exec diff ../outputs/t43 ../golden/t43 >/dev/null 2>&1 ;;
  p44) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst35 > ../outputs/t44
    exec diff ../outputs/t44 ../golden/t44 >/dev/null 2>&1 ;;
  p45) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst21 > ../outputs/t45
    exec diff ../outputs/t45 ../golden/t45 >/dev/null 2>&1 ;;
  p46) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst39 > ../outputs/t46
    exec diff ../outputs/t46 ../golden/t46 >/dev/null 2>&1 ;;
  p47) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst12 > ../outputs/t47
    exec diff ../outputs/t47 ../golden/t47 >/dev/null 2>&1 ;;
  p48) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst86 > ../outputs/t48
    exec diff ../outputs/t48 ../golden/t48 >/dev/null 2>&1 ;;
  p49) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst106 > ../outputs/t49
    exec diff ../outputs/t49 ../golden/t49 >/dev/null 2>&1 ;;
  p50) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst41 > ../outputs/t50
    exec diff ../outputs/t50 ../golden/t50 >/dev/null 2>&1 ;;
  p51) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst43 > ../outputs/t51
    exec diff ../outputs/t51 ../golden/t51 >/dev/null 2>&1 ;;
  p52) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst23 > ../outputs/t52
    exec diff ../outputs/t52 ../golden/t52 >/dev/null 2>&1 ;;
  p53) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst115 > ../outputs/t53
    exec diff ../outputs/t53 ../golden/t53 >/dev/null 2>&1 ;;
  p54) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst44 > ../outputs/t54
    exec diff ../outputs/t54 ../golden/t54 >/dev/null 2>&1 ;;
  p55) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst68 > ../outputs/t55
    exec diff ../outputs/t55 ../golden/t55 >/dev/null 2>&1 ;;
  p56) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst45 > ../outputs/t56
    exec diff ../outputs/t56 ../golden/t56 >/dev/null 2>&1 ;;
  p57) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst4 > ../outputs/t57
    exec diff ../outputs/t57 ../golden/t57 >/dev/null 2>&1 ;;
  p58) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst116 > ../outputs/t58
    exec diff ../outputs/t58 ../golden/t58 >/dev/null 2>&1 ;;
  p59) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst85 > ../outputs/t59
    exec diff ../outputs/t59 ../golden/t59 >/dev/null 2>&1 ;;
  p60) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst46 > ../outputs/t60
    exec diff ../outputs/t60 ../golden/t60 >/dev/null 2>&1 ;;
  p61) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst47 > ../outputs/t61
    exec diff ../outputs/t61 ../golden/t61 >/dev/null 2>&1 ;;
  p62) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst96 > ../outputs/t62
    exec diff ../outputs/t62 ../golden/t62 >/dev/null 2>&1 ;;
  p63) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst73 > ../outputs/t63
    exec diff ../outputs/t63 ../golden/t63 >/dev/null 2>&1 ;;
  p64) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst48 > ../outputs/t64
    exec diff ../outputs/t64 ../golden/t64 >/dev/null 2>&1 ;;
  p65) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst101 > ../outputs/t65
    exec diff ../outputs/t65 ../golden/t65 >/dev/null 2>&1 ;;
  p66) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst64 > ../outputs/t66
    exec diff ../outputs/t66 ../golden/t66 >/dev/null 2>&1 ;;
  p67) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst84 > ../outputs/t67
    exec diff ../outputs/t67 ../golden/t67 >/dev/null 2>&1 ;;
  p68) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst49 > ../outputs/t68
    exec diff ../outputs/t68 ../golden/t68 >/dev/null 2>&1 ;;
  p69) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst95 > ../outputs/t69
    exec diff ../outputs/t69 ../golden/t69 >/dev/null 2>&1 ;;
  p70) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst14 > ../outputs/t70
    exec diff ../outputs/t70 ../golden/t70 >/dev/null 2>&1 ;;
  p71) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst51 > ../outputs/t71
    exec diff ../outputs/t71 ../golden/t71 >/dev/null 2>&1 ;;
  p72) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst115 > ../outputs/t72
    exec diff ../outputs/t72 ../golden/t72 >/dev/null 2>&1 ;;
  p73) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst72 > ../outputs/t73
    exec diff ../outputs/t73 ../golden/t73 >/dev/null 2>&1 ;;
  p74) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst60 > ../outputs/t74
    exec diff ../outputs/t74 ../golden/t74 >/dev/null 2>&1 ;;
  p75) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst83 > ../outputs/t75
    exec diff ../outputs/t75 ../golden/t75 >/dev/null 2>&1 ;;
  p76) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst38 > ../outputs/t76
    exec diff ../outputs/t76 ../golden/t76 >/dev/null 2>&1 ;;
  p77) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst52 > ../outputs/t77
    exec diff ../outputs/t77 ../golden/t77 >/dev/null 2>&1 ;;
  p78) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst95 > ../outputs/t78
    exec diff ../outputs/t78 ../golden/t78 >/dev/null 2>&1 ;;
  p79) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst82 > ../outputs/t79
    exec diff ../outputs/t79 ../golden/t79 >/dev/null 2>&1 ;;
  p80) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst114 > ../outputs/t80
    exec diff ../outputs/t80 ../golden/t80 >/dev/null 2>&1 ;;
  p81) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst75 > ../outputs/t81
    exec diff ../outputs/t81 ../golden/t81 >/dev/null 2>&1 ;;
  p82) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst36 > ../outputs/t82
    exec diff ../outputs/t82 ../golden/t82 >/dev/null 2>&1 ;;
  p83) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst54 > ../outputs/t83
    exec diff ../outputs/t83 ../golden/t83 >/dev/null 2>&1 ;;
  p84) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst57 > ../outputs/t84
    exec diff ../outputs/t84 ../golden/t84 >/dev/null 2>&1 ;;
  p85) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst79 > ../outputs/t85
    exec diff ../outputs/t85 ../golden/t85 >/dev/null 2>&1 ;;
  p86) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst58 > ../outputs/t86
    exec diff ../outputs/t86 ../golden/t86 >/dev/null 2>&1 ;;
  p87) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst94 > ../outputs/t87
    exec diff ../outputs/t87 ../golden/t87 >/dev/null 2>&1 ;;
  p88) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst59 > ../outputs/t88
    exec diff ../outputs/t88 ../golden/t88 >/dev/null 2>&1 ;;
  p89) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst11 > ../outputs/t89
    exec diff ../outputs/t89 ../golden/t89 >/dev/null 2>&1 ;;
  p90) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst116 > ../outputs/t90
    exec diff ../outputs/t90 ../golden/t90 >/dev/null 2>&1 ;;
  p91) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst40 > ../outputs/t91
    exec diff ../outputs/t91 ../golden/t91 >/dev/null 2>&1 ;;
  p92) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst93 > ../outputs/t92
    exec diff ../outputs/t92 ../golden/t92 >/dev/null 2>&1 ;;
  p93) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst61 > ../outputs/t93
    exec diff ../outputs/t93 ../golden/t93 >/dev/null 2>&1 ;;
  p94) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst22 > ../outputs/t94
    exec diff ../outputs/t94 ../golden/t94 >/dev/null 2>&1 ;;
  p95) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst42 > ../outputs/t95
    exec diff ../outputs/t95 ../golden/t95 >/dev/null 2>&1 ;;
  p96) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst62 > ../outputs/t96
    exec diff ../outputs/t96 ../golden/t96 >/dev/null 2>&1 ;;
  p97) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst104 > ../outputs/t97
    exec diff ../outputs/t97 ../golden/t97 >/dev/null 2>&1 ;;
  p98) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst37 > ../outputs/t98
    exec diff ../outputs/t98 ../golden/t98 >/dev/null 2>&1 ;;
  p99) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst81 > ../outputs/t99
    exec diff ../outputs/t99 ../golden/t99 >/dev/null 2>&1 ;;
  p100) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst63 > ../outputs/t100
    exec diff ../outputs/t100 ../golden/t100 >/dev/null 2>&1 ;;
  p101) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst113 > ../outputs/t101
    exec diff ../outputs/t101 ../golden/t101 >/dev/null 2>&1 ;;
  p102) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst112 > ../outputs/t102
    exec diff ../outputs/t102 ../golden/t102 >/dev/null 2>&1 ;;
  p103) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst26 > ../outputs/t103
    exec diff ../outputs/t103 ../golden/t103 >/dev/null 2>&1 ;;
  p104) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst65 > ../outputs/t104
    exec diff ../outputs/t104 ../golden/t104 >/dev/null 2>&1 ;;
  p105) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst71 > ../outputs/t105
    exec diff ../outputs/t105 ../golden/t105 >/dev/null 2>&1 ;;
  p106) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst111 > ../outputs/t106
    exec diff ../outputs/t106 ../golden/t106 >/dev/null 2>&1 ;;
  p107) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst74 > ../outputs/t107
    exec diff ../outputs/t107 ../golden/t107 >/dev/null 2>&1 ;;
  p108) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst102 > ../outputs/t108
    exec diff ../outputs/t108 ../golden/t108 >/dev/null 2>&1 ;;
  p109) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst66 > ../outputs/t109
    exec diff ../outputs/t109 ../golden/t109 >/dev/null 2>&1 ;;
  p110) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst117 > ../outputs/t110
    exec diff ../outputs/t110 ../golden/t110 >/dev/null 2>&1 ;;
  p111) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst67 > ../outputs/t111
    exec diff ../outputs/t111 ../golden/t111 >/dev/null 2>&1 ;;
  p112) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst69 > ../outputs/t112
    exec diff ../outputs/t112 ../golden/t112 >/dev/null 2>&1 ;;
  p113) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst70 > ../outputs/t113
    exec diff ../outputs/t113 ../golden/t113 >/dev/null 2>&1 ;;
  p114) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst1 > ../outputs/t114
    exec diff ../outputs/t114 ../golden/t114 >/dev/null 2>&1 ;;
  p115) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst103 > ../outputs/t115
    exec diff ../outputs/t115 ../golden/t115 >/dev/null 2>&1 ;;
  p116) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst80 > ../outputs/t116
    exec diff ../outputs/t116 ../golden/t116 >/dev/null 2>&1 ;;
  p117) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test3 > ../outputs/t117
    exec diff ../outputs/t117 ../golden/t117 >/dev/null 2>&1 ;;
  p118) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test5 > ../outputs/t118
    exec diff ../outputs/t118 ../golden/t118 >/dev/null 2>&1 ;;
  p119) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test32 > ../outputs/t119
    exec diff ../outputs/t119 ../golden/t119 >/dev/null 2>&1 ;;
  p120) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test7 > ../outputs/t120
    exec diff ../outputs/t120 ../golden/t120 >/dev/null 2>&1 ;;
  p121) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test8 > ../outputs/t121
    exec diff ../outputs/t121 ../golden/t121 >/dev/null 2>&1 ;;
  p122) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test9 > ../outputs/t122
    exec diff ../outputs/t122 ../golden/t122 >/dev/null 2>&1 ;;
  p123) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test10 > ../outputs/t123
    exec diff ../outputs/t123 ../golden/t123 >/dev/null 2>&1 ;;
  p124) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test19 > ../outputs/t124
    exec diff ../outputs/t124 ../golden/t124 >/dev/null 2>&1 ;;
  p125) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test31 > ../outputs/t125
    exec diff ../outputs/t125 ../golden/t125 >/dev/null 2>&1 ;;
  p126) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test1 > ../outputs/t126
    exec diff ../outputs/t126 ../golden/t126 >/dev/null 2>&1 ;;
  p127) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test4 > ../outputs/t127
    exec diff ../outputs/t127 ../golden/t127 >/dev/null 2>&1 ;;
  p128) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test39 > ../outputs/t128
    exec diff ../outputs/t128 ../golden/t128 >/dev/null 2>&1 ;;
  p129) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test11 > ../outputs/t129
    exec diff ../outputs/t129 ../golden/t129 >/dev/null 2>&1 ;;
  p130) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test30 > ../outputs/t130
    exec diff ../outputs/t130 ../golden/t130 >/dev/null 2>&1 ;;
  p131) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test14 > ../outputs/t131
    exec diff ../outputs/t131 ../golden/t131 >/dev/null 2>&1 ;;
  p132) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test13 > ../outputs/t132
    exec diff ../outputs/t132 ../golden/t132 >/dev/null 2>&1 ;;
  p133) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test15 > ../outputs/t133
    exec diff ../outputs/t133 ../golden/t133 >/dev/null 2>&1 ;;
  p134) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test16 > ../outputs/t134
    exec diff ../outputs/t134 ../golden/t134 >/dev/null 2>&1 ;;
  p135) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test17 > ../outputs/t135
    exec diff ../outputs/t135 ../golden/t135 >/dev/null 2>&1 ;;
  p136) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test6 > ../outputs/t136
    exec diff ../outputs/t136 ../golden/t136 >/dev/null 2>&1 ;;
  p137) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test33 > ../outputs/t137
    exec diff ../outputs/t137 ../golden/t137 >/dev/null 2>&1 ;;
  p138) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test34 > ../outputs/t138
    exec diff ../outputs/t138 ../golden/t138 >/dev/null 2>&1 ;;
  p139) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test35 > ../outputs/t139
    exec diff ../outputs/t139 ../golden/t139 >/dev/null 2>&1 ;;
  p140) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test36 > ../outputs/t140
    exec diff ../outputs/t140 ../golden/t140 >/dev/null 2>&1 ;;
  p141) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test18 > ../outputs/t141
    exec diff ../outputs/t141 ../golden/t141 >/dev/null 2>&1 ;;
  p142) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test37 > ../outputs/t142
    exec diff ../outputs/t142 ../golden/t142 >/dev/null 2>&1 ;;
  p143) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test40 > ../outputs/t143
    exec diff ../outputs/t143 ../golden/t143 >/dev/null 2>&1 ;;
  p144) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test38 > ../outputs/t144
    exec diff ../outputs/t144 ../golden/t144 >/dev/null 2>&1 ;;
  p145) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tstt1.mat > ../outputs/t145
    exec diff ../outputs/t145 ../golden/t145 >/dev/null 2>&1 ;;
  p146) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jk2AAZ.mat > ../outputs/t146
    exec diff ../outputs/t146 ../golden/t146 >/dev/null 2>&1 ;;
  p147) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jk2ABS.mat > ../outputs/t147
    exec diff ../outputs/t147 ../golden/t147 >/dev/null 2>&1 ;;
  p148) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jk2ABk.mat > ../outputs/t148
    exec diff ../outputs/t148 ../golden/t148 >/dev/null 2>&1 ;;
  p149) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jk1AA_.mat > ../outputs/t149
    exec diff ../outputs/t149 ../golden/t149 >/dev/null 2>&1 ;;
  p150) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst29.mat > ../outputs/t150
    exec diff ../outputs/t150 ../golden/t150 >/dev/null 2>&1 ;;
  p151) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jk1AAS.mat > ../outputs/t151
    exec diff ../outputs/t151 ../golden/t151 >/dev/null 2>&1 ;;
  p152) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAY.mat > ../outputs/t152
    exec diff ../outputs/t152 ../golden/t152 >/dev/null 2>&1 ;;
  p153) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jk2AAy.mat > ../outputs/t153
    exec diff ../outputs/t153 ../golden/t153 >/dev/null 2>&1 ;;
  p154) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAQ.mat > ../outputs/t154
    exec diff ../outputs/t154 ../golden/t154 >/dev/null 2>&1 ;;
  p155) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst21.mat > ../outputs/t155
    exec diff ../outputs/t155 ../golden/t155 >/dev/null 2>&1 ;;
  p156) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAZ.mat > ../outputs/t156
    exec diff ../outputs/t156 ../golden/t156 >/dev/null 2>&1 ;;
  p157) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jk2ABq.mat > ../outputs/t157
    exec diff ../outputs/t157 ../golden/t157 >/dev/null 2>&1 ;;
  p158) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jk1ABq.mat > ../outputs/t158
    exec diff ../outputs/t158 ../golden/t158 >/dev/null 2>&1 ;;
  p159) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jk2AAX.mat > ../outputs/t159
    exec diff ../outputs/t159 ../golden/t159 >/dev/null 2>&1 ;;
  p160) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADr.mat > ../outputs/t160
    exec diff ../outputs/t160 ../golden/t160 >/dev/null 2>&1 ;;
  p161) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFi.mat > ../outputs/t161
    exec diff ../outputs/t161 ../golden/t161 >/dev/null 2>&1 ;;
  p162) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jk2AAS.mat > ../outputs/t162
    exec diff ../outputs/t162 ../golden/t162 >/dev/null 2>&1 ;;
  p163) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2f.mat > ../outputs/t163
    exec diff ../outputs/t163 ../golden/t163 >/dev/null 2>&1 ;;
  p164) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst23.mat > ../outputs/t164
    exec diff ../outputs/t164 ../golden/t164 >/dev/null 2>&1 ;;
  p165) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2E.mat > ../outputs/t165
    exec diff ../outputs/t165 ../golden/t165 >/dev/null 2>&1 ;;
  p166) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test72 > ../outputs/t166
    exec diff ../outputs/t166 ../golden/t166 >/dev/null 2>&1 ;;
  p167) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test77 > ../outputs/t167
    exec diff ../outputs/t167 ../golden/t167 >/dev/null 2>&1 ;;
  p168) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test80 > ../outputs/t168
    exec diff ../outputs/t168 ../golden/t168 >/dev/null 2>&1 ;;
  p169) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test51 > ../outputs/t169
    exec diff ../outputs/t169 ../golden/t169 >/dev/null 2>&1 ;;
  p170) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test52 > ../outputs/t170
    exec diff ../outputs/t170 ../golden/t170 >/dev/null 2>&1 ;;
  p171) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test53 > ../outputs/t171
    exec diff ../outputs/t171 ../golden/t171 >/dev/null 2>&1 ;;
  p172) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test54 > ../outputs/t172
    exec diff ../outputs/t172 ../golden/t172 >/dev/null 2>&1 ;;
  p173) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test56 > ../outputs/t173
    exec diff ../outputs/t173 ../golden/t173 >/dev/null 2>&1 ;;
  p174) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test57 > ../outputs/t174
    exec diff ../outputs/t174 ../golden/t174 >/dev/null 2>&1 ;;
  p175) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test60 > ../outputs/t175
    exec diff ../outputs/t175 ../golden/t175 >/dev/null 2>&1 ;;
  p176) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test42 > ../outputs/t176
    exec diff ../outputs/t176 ../golden/t176 >/dev/null 2>&1 ;;
  p177) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test75 > ../outputs/t177
    exec diff ../outputs/t177 ../golden/t177 >/dev/null 2>&1 ;;
  p178) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test73 > ../outputs/t178
    exec diff ../outputs/t178 ../golden/t178 >/dev/null 2>&1 ;;
  p179) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test99 > ../outputs/t179
    exec diff ../outputs/t179 ../golden/t179 >/dev/null 2>&1 ;;
  p180) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test43 > ../outputs/t180
    exec diff ../outputs/t180 ../golden/t180 >/dev/null 2>&1 ;;
  p181) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test90 > ../outputs/t181
    exec diff ../outputs/t181 ../golden/t181 >/dev/null 2>&1 ;;
  p182) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test45 > ../outputs/t182
    exec diff ../outputs/t182 ../golden/t182 >/dev/null 2>&1 ;;
  p183) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test46 > ../outputs/t183
    exec diff ../outputs/t183 ../golden/t183 >/dev/null 2>&1 ;;
  p184) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test78 > ../outputs/t184
    exec diff ../outputs/t184 ../golden/t184 >/dev/null 2>&1 ;;
  p185) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test83 > ../outputs/t185
    exec diff ../outputs/t185 ../golden/t185 >/dev/null 2>&1 ;;
  p186) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test59 > ../outputs/t186
    exec diff ../outputs/t186 ../golden/t186 >/dev/null 2>&1 ;;
  p187) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test49 > ../outputs/t187
    exec diff ../outputs/t187 ../golden/t187 >/dev/null 2>&1 ;;
  p188) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test50 > ../outputs/t188
    exec diff ../outputs/t188 ../golden/t188 >/dev/null 2>&1 ;;
  p189) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test61 > ../outputs/t189
    exec diff ../outputs/t189 ../golden/t189 >/dev/null 2>&1 ;;
  p190) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test63 > ../outputs/t190
    exec diff ../outputs/t190 ../golden/t190 >/dev/null 2>&1 ;;
  p191) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test74 > ../outputs/t191
    exec diff ../outputs/t191 ../golden/t191 >/dev/null 2>&1 ;;
  p192) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test64 > ../outputs/t192
    exec diff ../outputs/t192 ../golden/t192 >/dev/null 2>&1 ;;
  p193) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test79 > ../outputs/t193
    exec diff ../outputs/t193 ../golden/t193 >/dev/null 2>&1 ;;
  p194) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test87 > ../outputs/t194
    exec diff ../outputs/t194 ../golden/t194 >/dev/null 2>&1 ;;
  p195) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test66 > ../outputs/t195
    exec diff ../outputs/t195 ../golden/t195 >/dev/null 2>&1 ;;
  p196) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test67 > ../outputs/t196
    exec diff ../outputs/t196 ../golden/t196 >/dev/null 2>&1 ;;
  p197) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test48 > ../outputs/t197
    exec diff ../outputs/t197 ../golden/t197 >/dev/null 2>&1 ;;
  p198) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test100 > ../outputs/t198
    exec diff ../outputs/t198 ../golden/t198 >/dev/null 2>&1 ;;
  p199) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test92 > ../outputs/t199
    exec diff ../outputs/t199 ../golden/t199 >/dev/null 2>&1 ;;
  p200) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test68 > ../outputs/t200
    exec diff ../outputs/t200 ../golden/t200 >/dev/null 2>&1 ;;
  p201) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test76 > ../outputs/t201
    exec diff ../outputs/t201 ../golden/t201 >/dev/null 2>&1 ;;
  p202) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test69 > ../outputs/t202
    exec diff ../outputs/t202 ../golden/t202 >/dev/null 2>&1 ;;
  p203) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test44 > ../outputs/t203
    exec diff ../outputs/t203 ../golden/t203 >/dev/null 2>&1 ;;
  p204) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test47 > ../outputs/t204
    exec diff ../outputs/t204 ../golden/t204 >/dev/null 2>&1 ;;
  p205) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test81 > ../outputs/t205
    exec diff ../outputs/t205 ../golden/t205 >/dev/null 2>&1 ;;
  p206) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test84 > ../outputs/t206
    exec diff ../outputs/t206 ../golden/t206 >/dev/null 2>&1 ;;
  p207) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test98 > ../outputs/t207
    exec diff ../outputs/t207 ../golden/t207 >/dev/null 2>&1 ;;
  p208) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test58 > ../outputs/t208
    exec diff ../outputs/t208 ../golden/t208 >/dev/null 2>&1 ;;
  p209) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test88 > ../outputs/t209
    exec diff ../outputs/t209 ../golden/t209 >/dev/null 2>&1 ;;
  p210) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test89 > ../outputs/t210
    exec diff ../outputs/t210 ../golden/t210 >/dev/null 2>&1 ;;
  p211) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test91 > ../outputs/t211
    exec diff ../outputs/t211 ../golden/t211 >/dev/null 2>&1 ;;
  p212) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test70 > ../outputs/t212
    exec diff ../outputs/t212 ../golden/t212 >/dev/null 2>&1 ;;
  p213) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test82 > ../outputs/t213
    exec diff ../outputs/t213 ../golden/t213 >/dev/null 2>&1 ;;
  p214) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test93 > ../outputs/t214
    exec diff ../outputs/t214 ../golden/t214 >/dev/null 2>&1 ;;
  p215) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test94 > ../outputs/t215
    exec diff ../outputs/t215 ../golden/t215 >/dev/null 2>&1 ;;
  p216) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test65 > ../outputs/t216
    exec diff ../outputs/t216 ../golden/t216 >/dev/null 2>&1 ;;
  p217) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test71 > ../outputs/t217
    exec diff ../outputs/t217 ../golden/t217 >/dev/null 2>&1 ;;
  p218) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test85 > ../outputs/t218
    exec diff ../outputs/t218 ../golden/t218 >/dev/null 2>&1 ;;
  p219) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test101 > ../outputs/t219
    exec diff ../outputs/t219 ../golden/t219 >/dev/null 2>&1 ;;
  p220) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test102 > ../outputs/t220
    exec diff ../outputs/t220 ../golden/t220 >/dev/null 2>&1 ;;
  p221) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test103 > ../outputs/t221
    exec diff ../outputs/t221 ../golden/t221 >/dev/null 2>&1 ;;
  p222) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test104 > ../outputs/t222
    exec diff ../outputs/t222 ../golden/t222 >/dev/null 2>&1 ;;
  p223) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test105 > ../outputs/t223
    exec diff ../outputs/t223 ../golden/t223 >/dev/null 2>&1 ;;
  p224) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test106 > ../outputs/t224
    exec diff ../outputs/t224 ../golden/t224 >/dev/null 2>&1 ;;
  p225) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test107 > ../outputs/t225
    exec diff ../outputs/t225 ../golden/t225 >/dev/null 2>&1 ;;
  p226) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test108 > ../outputs/t226
    exec diff ../outputs/t226 ../golden/t226 >/dev/null 2>&1 ;;
  p227) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test1.inc > ../outputs/t227
    exec diff ../outputs/t227 ../golden/t227 >/dev/null 2>&1 ;;
  p228) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test3.inc > ../outputs/t228
    exec diff ../outputs/t228 ../golden/t228 >/dev/null 2>&1 ;;
  p229) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test4.inc > ../outputs/t229
    exec diff ../outputs/t229 ../golden/t229 >/dev/null 2>&1 ;;
  p230) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test5.inc > ../outputs/t230
    exec diff ../outputs/t230 ../golden/t230 >/dev/null 2>&1 ;;
  p231) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test6.inc > ../outputs/t231
    exec diff ../outputs/t231 ../golden/t231 >/dev/null 2>&1 ;;
  p232) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test7.inc > ../outputs/t232
    exec diff ../outputs/t232 ../golden/t232 >/dev/null 2>&1 ;;
  p233) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test8.inc > ../outputs/t233
    exec diff ../outputs/t233 ../golden/t233 >/dev/null 2>&1 ;;
  p234) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test9.inc > ../outputs/t234
    exec diff ../outputs/t234 ../golden/t234 >/dev/null 2>&1 ;;
  p235) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test10.inc > ../outputs/t235
    exec diff ../outputs/t235 ../golden/t235 >/dev/null 2>&1 ;;
  p236) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test11.inc > ../outputs/t236
    exec diff ../outputs/t236 ../golden/t236 >/dev/null 2>&1 ;;
  p237) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test13.inc > ../outputs/t237
    exec diff ../outputs/t237 ../golden/t237 >/dev/null 2>&1 ;;
  p238) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test14.inc > ../outputs/t238
    exec diff ../outputs/t238 ../golden/t238 >/dev/null 2>&1 ;;
  p239) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test15.inc > ../outputs/t239
    exec diff ../outputs/t239 ../golden/t239 >/dev/null 2>&1 ;;
  p240) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test16.inc > ../outputs/t240
    exec diff ../outputs/t240 ../golden/t240 >/dev/null 2>&1 ;;
  p241) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test17.inc > ../outputs/t241
    exec diff ../outputs/t241 ../golden/t241 >/dev/null 2>&1 ;;
  p242) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test18.inc > ../outputs/t242
    exec diff ../outputs/t242 ../golden/t242 >/dev/null 2>&1 ;;
  p243) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test19.inc > ../outputs/t243
    exec diff ../outputs/t243 ../golden/t243 >/dev/null 2>&1 ;;
  p244) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test20.inc > ../outputs/t244
    exec diff ../outputs/t244 ../golden/t244 >/dev/null 2>&1 ;;
  p245) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test21.inc > ../outputs/t245
    exec diff ../outputs/t245 ../golden/t245 >/dev/null 2>&1 ;;
  p246) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test22.inc > ../outputs/t246
    exec diff ../outputs/t246 ../golden/t246 >/dev/null 2>&1 ;;
  p247) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test23.inc > ../outputs/t247
    exec diff ../outputs/t247 ../golden/t247 >/dev/null 2>&1 ;;
  p248) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test24.inc > ../outputs/t248
    exec diff ../outputs/t248 ../golden/t248 >/dev/null 2>&1 ;;
  p249) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test25.inc > ../outputs/t249
    exec diff ../outputs/t249 ../golden/t249 >/dev/null 2>&1 ;;
  p250) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test26.inc > ../outputs/t250
    exec diff ../outputs/t250 ../golden/t250 >/dev/null 2>&1 ;;
  p251) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test27.inc > ../outputs/t251
    exec diff ../outputs/t251 ../golden/t251 >/dev/null 2>&1 ;;
  p252) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test28.inc > ../outputs/t252
    exec diff ../outputs/t252 ../golden/t252 >/dev/null 2>&1 ;;
  p253) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test29.inc > ../outputs/t253
    exec diff ../outputs/t253 ../golden/t253 >/dev/null 2>&1 ;;
  p254) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test30.inc > ../outputs/t254
    exec diff ../outputs/t254 ../golden/t254 >/dev/null 2>&1 ;;
  p255) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test31.inc > ../outputs/t255
    exec diff ../outputs/t255 ../golden/t255 >/dev/null 2>&1 ;;
  p256) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test32.inc > ../outputs/t256
    exec diff ../outputs/t256 ../golden/t256 >/dev/null 2>&1 ;;
  p257) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test33.inc > ../outputs/t257
    exec diff ../outputs/t257 ../golden/t257 >/dev/null 2>&1 ;;
  p258) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test34.inc > ../outputs/t258
    exec diff ../outputs/t258 ../golden/t258 >/dev/null 2>&1 ;;
  p259) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test35.inc > ../outputs/t259
    exec diff ../outputs/t259 ../golden/t259 >/dev/null 2>&1 ;;
  p260) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test36.inc > ../outputs/t260
    exec diff ../outputs/t260 ../golden/t260 >/dev/null 2>&1 ;;
  p261) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test37.inc > ../outputs/t261
    exec diff ../outputs/t261 ../golden/t261 >/dev/null 2>&1 ;;
  p262) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test38.inc > ../outputs/t262
    exec diff ../outputs/t262 ../golden/t262 >/dev/null 2>&1 ;;
  p263) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test39.inc > ../outputs/t263
    exec diff ../outputs/t263 ../golden/t263 >/dev/null 2>&1 ;;
  p264) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test40.inc > ../outputs/t264
    exec diff ../outputs/t264 ../golden/t264 >/dev/null 2>&1 ;;
  p265) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test41.inc > ../outputs/t265
    exec diff ../outputs/t265 ../golden/t265 >/dev/null 2>&1 ;;
  p266) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test42.inc > ../outputs/t266
    exec diff ../outputs/t266 ../golden/t266 >/dev/null 2>&1 ;;
  p267) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test43.inc > ../outputs/t267
    exec diff ../outputs/t267 ../golden/t267 >/dev/null 2>&1 ;;
  p268) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test44.inc > ../outputs/t268
    exec diff ../outputs/t268 ../golden/t268 >/dev/null 2>&1 ;;
  p269) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test45.inc > ../outputs/t269
    exec diff ../outputs/t269 ../golden/t269 >/dev/null 2>&1 ;;
  p270) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test46.inc > ../outputs/t270
    exec diff ../outputs/t270 ../golden/t270 >/dev/null 2>&1 ;;
  p271) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test47.inc > ../outputs/t271
    exec diff ../outputs/t271 ../golden/t271 >/dev/null 2>&1 ;;
  p272) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test48.inc > ../outputs/t272
    exec diff ../outputs/t272 ../golden/t272 >/dev/null 2>&1 ;;
  p273) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test49.inc > ../outputs/t273
    exec diff ../outputs/t273 ../golden/t273 >/dev/null 2>&1 ;;
  p274) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test50.inc > ../outputs/t274
    exec diff ../outputs/t274 ../golden/t274 >/dev/null 2>&1 ;;
  p275) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test51.inc > ../outputs/t275
    exec diff ../outputs/t275 ../golden/t275 >/dev/null 2>&1 ;;
  p276) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test52.inc > ../outputs/t276
    exec diff ../outputs/t276 ../golden/t276 >/dev/null 2>&1 ;;
  p277) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test53.inc > ../outputs/t277
    exec diff ../outputs/t277 ../golden/t277 >/dev/null 2>&1 ;;
  p278) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test54.inc > ../outputs/t278
    exec diff ../outputs/t278 ../golden/t278 >/dev/null 2>&1 ;;
  p279) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test55.inc > ../outputs/t279
    exec diff ../outputs/t279 ../golden/t279 >/dev/null 2>&1 ;;
  p280) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test56.inc > ../outputs/t280
    exec diff ../outputs/t280 ../golden/t280 >/dev/null 2>&1 ;;
  p281) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test57.inc > ../outputs/t281
    exec diff ../outputs/t281 ../golden/t281 >/dev/null 2>&1 ;;
  p282) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test58.inc > ../outputs/t282
    exec diff ../outputs/t282 ../golden/t282 >/dev/null 2>&1 ;;
  p283) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test59.inc > ../outputs/t283
    exec diff ../outputs/t283 ../golden/t283 >/dev/null 2>&1 ;;
  p284) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test60.inc > ../outputs/t284
    exec diff ../outputs/t284 ../golden/t284 >/dev/null 2>&1 ;;
  p285) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test61.inc > ../outputs/t285
    exec diff ../outputs/t285 ../golden/t285 >/dev/null 2>&1 ;;
  p286) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test62.inc > ../outputs/t286
    exec diff ../outputs/t286 ../golden/t286 >/dev/null 2>&1 ;;
  p287) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test63.inc > ../outputs/t287
    exec diff ../outputs/t287 ../golden/t287 >/dev/null 2>&1 ;;
  p288) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test64.inc > ../outputs/t288
    exec diff ../outputs/t288 ../golden/t288 >/dev/null 2>&1 ;;
  p289) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test65.inc > ../outputs/t289
    exec diff ../outputs/t289 ../golden/t289 >/dev/null 2>&1 ;;
  p290) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test66.inc > ../outputs/t290
    exec diff ../outputs/t290 ../golden/t290 >/dev/null 2>&1 ;;
  p291) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test67.inc > ../outputs/t291
    exec diff ../outputs/t291 ../golden/t291 >/dev/null 2>&1 ;;
  p292) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test68.inc > ../outputs/t292
    exec diff ../outputs/t292 ../golden/t292 >/dev/null 2>&1 ;;
  p293) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test69.inc > ../outputs/t293
    exec diff ../outputs/t293 ../golden/t293 >/dev/null 2>&1 ;;
  p294) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test70.inc > ../outputs/t294
    exec diff ../outputs/t294 ../golden/t294 >/dev/null 2>&1 ;;
  p295) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test71.inc > ../outputs/t295
    exec diff ../outputs/t295 ../golden/t295 >/dev/null 2>&1 ;;
  p296) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test72.inc > ../outputs/t296
    exec diff ../outputs/t296 ../golden/t296 >/dev/null 2>&1 ;;
  p297) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test73.inc > ../outputs/t297
    exec diff ../outputs/t297 ../golden/t297 >/dev/null 2>&1 ;;
  p298) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test74.inc > ../outputs/t298
    exec diff ../outputs/t298 ../golden/t298 >/dev/null 2>&1 ;;
  p299) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test75.inc > ../outputs/t299
    exec diff ../outputs/t299 ../golden/t299 >/dev/null 2>&1 ;;
  p300) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test76.inc > ../outputs/t300
    exec diff ../outputs/t300 ../golden/t300 >/dev/null 2>&1 ;;
  p301) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test77.inc > ../outputs/t301
    exec diff ../outputs/t301 ../golden/t301 >/dev/null 2>&1 ;;
  p302) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test78.inc > ../outputs/t302
    exec diff ../outputs/t302 ../golden/t302 >/dev/null 2>&1 ;;
  p303) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test79.inc > ../outputs/t303
    exec diff ../outputs/t303 ../golden/t303 >/dev/null 2>&1 ;;
  p304) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test80.inc > ../outputs/t304
    exec diff ../outputs/t304 ../golden/t304 >/dev/null 2>&1 ;;
  p305) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test81.inc > ../outputs/t305
    exec diff ../outputs/t305 ../golden/t305 >/dev/null 2>&1 ;;
  p306) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test82.inc > ../outputs/t306
    exec diff ../outputs/t306 ../golden/t306 >/dev/null 2>&1 ;;
  p307) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test83.inc > ../outputs/t307
    exec diff ../outputs/t307 ../golden/t307 >/dev/null 2>&1 ;;
  p308) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test84.inc > ../outputs/t308
    exec diff ../outputs/t308 ../golden/t308 >/dev/null 2>&1 ;;
  p309) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test85.inc > ../outputs/t309
    exec diff ../outputs/t309 ../golden/t309 >/dev/null 2>&1 ;;
  p310) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test86.inc > ../outputs/t310
    exec diff ../outputs/t310 ../golden/t310 >/dev/null 2>&1 ;;
  p311) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test87.inc > ../outputs/t311
    exec diff ../outputs/t311 ../golden/t311 >/dev/null 2>&1 ;;
  p312) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test88.inc > ../outputs/t312
    exec diff ../outputs/t312 ../golden/t312 >/dev/null 2>&1 ;;
  p313) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test89.inc > ../outputs/t313
    exec diff ../outputs/t313 ../golden/t313 >/dev/null 2>&1 ;;
  p314) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test90.inc > ../outputs/t314
    exec diff ../outputs/t314 ../golden/t314 >/dev/null 2>&1 ;;
  p315) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test91.inc > ../outputs/t315
    exec diff ../outputs/t315 ../golden/t315 >/dev/null 2>&1 ;;
  p316) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test92.inc > ../outputs/t316
    exec diff ../outputs/t316 ../golden/t316 >/dev/null 2>&1 ;;
  p317) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test93.inc > ../outputs/t317
    exec diff ../outputs/t317 ../golden/t317 >/dev/null 2>&1 ;;
  p318) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test94.inc > ../outputs/t318
    exec diff ../outputs/t318 ../golden/t318 >/dev/null 2>&1 ;;
  p319) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test95.inc > ../outputs/t319
    exec diff ../outputs/t319 ../golden/t319 >/dev/null 2>&1 ;;
  p320) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test96.inc > ../outputs/t320
    exec diff ../outputs/t320 ../golden/t320 >/dev/null 2>&1 ;;
  p321) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test97.inc > ../outputs/t321
    exec diff ../outputs/t321 ../golden/t321 >/dev/null 2>&1 ;;
  p322) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test98.inc > ../outputs/t322
    exec diff ../outputs/t322 ../golden/t322 >/dev/null 2>&1 ;;
  p323) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test99.inc > ../outputs/t323
    exec diff ../outputs/t323 ../golden/t323 >/dev/null 2>&1 ;;
  p324) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test100.inc > ../outputs/t324
    exec diff ../outputs/t324 ../golden/t324 >/dev/null 2>&1 ;;
  p325) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test101.inc > ../outputs/t325
    exec diff ../outputs/t325 ../golden/t325 >/dev/null 2>&1 ;;
  p326) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test102.inc > ../outputs/t326
    exec diff ../outputs/t326 ../golden/t326 >/dev/null 2>&1 ;;
  p327) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test103.inc > ../outputs/t327
    exec diff ../outputs/t327 ../golden/t327 >/dev/null 2>&1 ;;
  p328) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test104.inc > ../outputs/t328
    exec diff ../outputs/t328 ../golden/t328 >/dev/null 2>&1 ;;
  p329) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test106.inc > ../outputs/t329
    exec diff ../outputs/t329 ../golden/t329 >/dev/null 2>&1 ;;
  p330) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test107.inc > ../outputs/t330
    exec diff ../outputs/t330 ../golden/t330 >/dev/null 2>&1 ;;
  p331) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test108.inc > ../outputs/t331
    exec diff ../outputs/t331 ../golden/t331 >/dev/null 2>&1 ;;
  p332) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test109.inc > ../outputs/t332
    exec diff ../outputs/t332 ../golden/t332 >/dev/null 2>&1 ;;
  p333) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test110.inc > ../outputs/t333
    exec diff ../outputs/t333 ../golden/t333 >/dev/null 2>&1 ;;
  p334) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test111.inc > ../outputs/t334
    exec diff ../outputs/t334 ../golden/t334 >/dev/null 2>&1 ;;
  p335) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test112.inc > ../outputs/t335
    exec diff ../outputs/t335 ../golden/t335 >/dev/null 2>&1 ;;
  p336) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test113.inc > ../outputs/t336
    exec diff ../outputs/t336 ../golden/t336 >/dev/null 2>&1 ;;
  p337) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test114.inc > ../outputs/t337
    exec diff ../outputs/t337 ../golden/t337 >/dev/null 2>&1 ;;
  p338) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test115.inc > ../outputs/t338
    exec diff ../outputs/t338 ../golden/t338 >/dev/null 2>&1 ;;
  p339) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test116.inc > ../outputs/t339
    exec diff ../outputs/t339 ../golden/t339 >/dev/null 2>&1 ;;
  p340) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test117.inc > ../outputs/t340
    exec diff ../outputs/t340 ../golden/t340 >/dev/null 2>&1 ;;
  p341) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test118.inc > ../outputs/t341
    exec diff ../outputs/t341 ../golden/t341 >/dev/null 2>&1 ;;
  p342) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test119.inc > ../outputs/t342
    exec diff ../outputs/t342 ../golden/t342 >/dev/null 2>&1 ;;
  p343) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test120.inc > ../outputs/t343
    exec diff ../outputs/t343 ../golden/t343 >/dev/null 2>&1 ;;
  p344) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test121.inc > ../outputs/t344
    exec diff ../outputs/t344 ../golden/t344 >/dev/null 2>&1 ;;
  p345) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test122.inc > ../outputs/t345
    exec diff ../outputs/t345 ../golden/t345 >/dev/null 2>&1 ;;
  p346) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test123.inc > ../outputs/t346
    exec diff ../outputs/t346 ../golden/t346 >/dev/null 2>&1 ;;
  p347) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test124.inc > ../outputs/t347
    exec diff ../outputs/t347 ../golden/t347 >/dev/null 2>&1 ;;
  p348) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test125.inc > ../outputs/t348
    exec diff ../outputs/t348 ../golden/t348 >/dev/null 2>&1 ;;
  p349) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test126.inc > ../outputs/t349
    exec diff ../outputs/t349 ../golden/t349 >/dev/null 2>&1 ;;
  p350) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test127.inc > ../outputs/t350
    exec diff ../outputs/t350 ../golden/t350 >/dev/null 2>&1 ;;
  p351) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test128.inc > ../outputs/t351
    exec diff ../outputs/t351 ../golden/t351 >/dev/null 2>&1 ;;
  p352) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test129.inc > ../outputs/t352
    exec diff ../outputs/t352 ../golden/t352 >/dev/null 2>&1 ;;
  p353) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test130.inc > ../outputs/t353
    exec diff ../outputs/t353 ../golden/t353 >/dev/null 2>&1 ;;
  p354) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test131.inc > ../outputs/t354
    exec diff ../outputs/t354 ../golden/t354 >/dev/null 2>&1 ;;
  p355) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test132.inc > ../outputs/t355
    exec diff ../outputs/t355 ../golden/t355 >/dev/null 2>&1 ;;
  p356) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test133.inc > ../outputs/t356
    exec diff ../outputs/t356 ../golden/t356 >/dev/null 2>&1 ;;
  p357) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test134.inc > ../outputs/t357
    exec diff ../outputs/t357 ../golden/t357 >/dev/null 2>&1 ;;
  p358) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test135.inc > ../outputs/t358
    exec diff ../outputs/t358 ../golden/t358 >/dev/null 2>&1 ;;
  p359) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test136.inc > ../outputs/t359
    exec diff ../outputs/t359 ../golden/t359 >/dev/null 2>&1 ;;
  p360) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test137.inc > ../outputs/t360
    exec diff ../outputs/t360 ../golden/t360 >/dev/null 2>&1 ;;
  p361) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test138.inc > ../outputs/t361
    exec diff ../outputs/t361 ../golden/t361 >/dev/null 2>&1 ;;
  p362) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test139.inc > ../outputs/t362
    exec diff ../outputs/t362 ../golden/t362 >/dev/null 2>&1 ;;
  p363) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test140.inc	 > ../outputs/t363
    exec diff ../outputs/t363 ../golden/t363 >/dev/null 2>&1 ;;
  p364) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test141.inc > ../outputs/t364
    exec diff ../outputs/t364 ../golden/t364 >/dev/null 2>&1 ;;
  p365) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test142.inc > ../outputs/t365
    exec diff ../outputs/t365 ../golden/t365 >/dev/null 2>&1 ;;
  p366) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test143.inc > ../outputs/t366
    exec diff ../outputs/t366 ../golden/t366 >/dev/null 2>&1 ;;
  p367) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test144.inc > ../outputs/t367
    exec diff ../outputs/t367 ../golden/t367 >/dev/null 2>&1 ;;
  p368) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test145.inc > ../outputs/t368
    exec diff ../outputs/t368 ../golden/t368 >/dev/null 2>&1 ;;
  p369) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test146.inc > ../outputs/t369
    exec diff ../outputs/t369 ../golden/t369 >/dev/null 2>&1 ;;
  p370) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test147.inc > ../outputs/t370
    exec diff ../outputs/t370 ../golden/t370 >/dev/null 2>&1 ;;
  p371) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test148.inc > ../outputs/t371
    exec diff ../outputs/t371 ../golden/t371 >/dev/null 2>&1 ;;
  p372) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test149.inc > ../outputs/t372
    exec diff ../outputs/t372 ../golden/t372 >/dev/null 2>&1 ;;
  p373) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test151.inc > ../outputs/t373
    exec diff ../outputs/t373 ../golden/t373 >/dev/null 2>&1 ;;
  p374) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test152.inc > ../outputs/t374
    exec diff ../outputs/t374 ../golden/t374 >/dev/null 2>&1 ;;
  p375) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test153.inc > ../outputs/t375
    exec diff ../outputs/t375 ../golden/t375 >/dev/null 2>&1 ;;
  p376) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test154.inc > ../outputs/t376
    exec diff ../outputs/t376 ../golden/t376 >/dev/null 2>&1 ;;
  p377) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test155.inc > ../outputs/t377
    exec diff ../outputs/t377 ../golden/t377 >/dev/null 2>&1 ;;
  p378) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test156.inc > ../outputs/t378
    exec diff ../outputs/t378 ../golden/t378 >/dev/null 2>&1 ;;
  p379) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test157.inc > ../outputs/t379
    exec diff ../outputs/t379 ../golden/t379 >/dev/null 2>&1 ;;
  p380) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test158.inc > ../outputs/t380
    exec diff ../outputs/t380 ../golden/t380 >/dev/null 2>&1 ;;
  p381) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test159.inc > ../outputs/t381
    exec diff ../outputs/t381 ../golden/t381 >/dev/null 2>&1 ;;
  p382) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test160.inc > ../outputs/t382
    exec diff ../outputs/t382 ../golden/t382 >/dev/null 2>&1 ;;
  p383) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test161.inc > ../outputs/t383
    exec diff ../outputs/t383 ../golden/t383 >/dev/null 2>&1 ;;
  p384) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test162.inc > ../outputs/t384
    exec diff ../outputs/t384 ../golden/t384 >/dev/null 2>&1 ;;
  p385) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test163.inc > ../outputs/t385
    exec diff ../outputs/t385 ../golden/t385 >/dev/null 2>&1 ;;
  p386) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test164.inc > ../outputs/t386
    exec diff ../outputs/t386 ../golden/t386 >/dev/null 2>&1 ;;
  p387) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test165.inc > ../outputs/t387
    exec diff ../outputs/t387 ../golden/t387 >/dev/null 2>&1 ;;
  p388) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test166.inc > ../outputs/t388
    exec diff ../outputs/t388 ../golden/t388 >/dev/null 2>&1 ;;
  p389) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test167.inc > ../outputs/t389
    exec diff ../outputs/t389 ../golden/t389 >/dev/null 2>&1 ;;
  p390) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test168.inc > ../outputs/t390
    exec diff ../outputs/t390 ../golden/t390 >/dev/null 2>&1 ;;
  p391) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test169.inc > ../outputs/t391
    exec diff ../outputs/t391 ../golden/t391 >/dev/null 2>&1 ;;
  p392) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test170.inc > ../outputs/t392
    exec diff ../outputs/t392 ../golden/t392 >/dev/null 2>&1 ;;
  p393) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test171.inc > ../outputs/t393
    exec diff ../outputs/t393 ../golden/t393 >/dev/null 2>&1 ;;
  p394) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test172.inc > ../outputs/t394
    exec diff ../outputs/t394 ../golden/t394 >/dev/null 2>&1 ;;
  p395) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test173.inc > ../outputs/t395
    exec diff ../outputs/t395 ../golden/t395 >/dev/null 2>&1 ;;
  p396) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test174.inc > ../outputs/t396
    exec diff ../outputs/t396 ../golden/t396 >/dev/null 2>&1 ;;
  p397) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test175.inc > ../outputs/t397
    exec diff ../outputs/t397 ../golden/t397 >/dev/null 2>&1 ;;
  p398) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test176.inc > ../outputs/t398
    exec diff ../outputs/t398 ../golden/t398 >/dev/null 2>&1 ;;
  p399) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test177.inc > ../outputs/t399
    exec diff ../outputs/t399 ../golden/t399 >/dev/null 2>&1 ;;
  p400) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test178.inc > ../outputs/t400
    exec diff ../outputs/t400 ../golden/t400 >/dev/null 2>&1 ;;
  p401) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test179.inc > ../outputs/t401
    exec diff ../outputs/t401 ../golden/t401 >/dev/null 2>&1 ;;
  p402) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test180.inc > ../outputs/t402
    exec diff ../outputs/t402 ../golden/t402 >/dev/null 2>&1 ;;
  p403) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test181.inc > ../outputs/t403
    exec diff ../outputs/t403 ../golden/t403 >/dev/null 2>&1 ;;
  p404) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test182.inc > ../outputs/t404
    exec diff ../outputs/t404 ../golden/t404 >/dev/null 2>&1 ;;
  p405) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test183.inc > ../outputs/t405
    exec diff ../outputs/t405 ../golden/t405 >/dev/null 2>&1 ;;
  p406) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test184.inc > ../outputs/t406
    exec diff ../outputs/t406 ../golden/t406 >/dev/null 2>&1 ;;
  p407) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test185.inc > ../outputs/t407
    exec diff ../outputs/t407 ../golden/t407 >/dev/null 2>&1 ;;
  p408) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test186.inc > ../outputs/t408
    exec diff ../outputs/t408 ../golden/t408 >/dev/null 2>&1 ;;
  p409) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test187.inc > ../outputs/t409
    exec diff ../outputs/t409 ../golden/t409 >/dev/null 2>&1 ;;
  p410) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test188.inc > ../outputs/t410
    exec diff ../outputs/t410 ../golden/t410 >/dev/null 2>&1 ;;
  p411) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test189.inc > ../outputs/t411
    exec diff ../outputs/t411 ../golden/t411 >/dev/null 2>&1 ;;
  p412) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test190.inc > ../outputs/t412
    exec diff ../outputs/t412 ../golden/t412 >/dev/null 2>&1 ;;
  p413) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test191.inc > ../outputs/t413
    exec diff ../outputs/t413 ../golden/t413 >/dev/null 2>&1 ;;
  p414) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test192.inc > ../outputs/t414
    exec diff ../outputs/t414 ../golden/t414 >/dev/null 2>&1 ;;
  p415) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test193.inc > ../outputs/t415
    exec diff ../outputs/t415 ../golden/t415 >/dev/null 2>&1 ;;
  p416) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test194.inc > ../outputs/t416
    exec diff ../outputs/t416 ../golden/t416 >/dev/null 2>&1 ;;
  p417) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test195.inc > ../outputs/t417
    exec diff ../outputs/t417 ../golden/t417 >/dev/null 2>&1 ;;
  p418) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test196.inc > ../outputs/t418
    exec diff ../outputs/t418 ../golden/t418 >/dev/null 2>&1 ;;
  p419) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test197.inc > ../outputs/t419
    exec diff ../outputs/t419 ../golden/t419 >/dev/null 2>&1 ;;
  p420) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test198.inc > ../outputs/t420
    exec diff ../outputs/t420 ../golden/t420 >/dev/null 2>&1 ;;
  p421) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test199.inc > ../outputs/t421
    exec diff ../outputs/t421 ../golden/t421 >/dev/null 2>&1 ;;
  p422) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test300.inc > ../outputs/t422
    exec diff ../outputs/t422 ../golden/t422 >/dev/null 2>&1 ;;
  p423) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test301.inc > ../outputs/t423
    exec diff ../outputs/t423 ../golden/t423 >/dev/null 2>&1 ;;
  p424) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test302.inc > ../outputs/t424
    exec diff ../outputs/t424 ../golden/t424 >/dev/null 2>&1 ;;
  p425) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test303.inc > ../outputs/t425
    exec diff ../outputs/t425 ../golden/t425 >/dev/null 2>&1 ;;
  p426) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test304.inc > ../outputs/t426
    exec diff ../outputs/t426 ../golden/t426 >/dev/null 2>&1 ;;
  p427) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test305.inc > ../outputs/t427
    exec diff ../outputs/t427 ../golden/t427 >/dev/null 2>&1 ;;
  p428) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test306.inc > ../outputs/t428
    exec diff ../outputs/t428 ../golden/t428 >/dev/null 2>&1 ;;
  p429) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test307.inc > ../outputs/t429
    exec diff ../outputs/t429 ../golden/t429 >/dev/null 2>&1 ;;
  p430) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test308.inc > ../outputs/t430
    exec diff ../outputs/t430 ../golden/t430 >/dev/null 2>&1 ;;
  p431) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test309.inc > ../outputs/t431
    exec diff ../outputs/t431 ../golden/t431 >/dev/null 2>&1 ;;
  p432) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test310.inc > ../outputs/t432
    exec diff ../outputs/t432 ../golden/t432 >/dev/null 2>&1 ;;
  p433) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test311.inc > ../outputs/t433
    exec diff ../outputs/t433 ../golden/t433 >/dev/null 2>&1 ;;
  p434) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test312.inc > ../outputs/t434
    exec diff ../outputs/t434 ../golden/t434 >/dev/null 2>&1 ;;
  p435) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test313.inc > ../outputs/t435
    exec diff ../outputs/t435 ../golden/t435 >/dev/null 2>&1 ;;
  p436) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test314.inc > ../outputs/t436
    exec diff ../outputs/t436 ../golden/t436 >/dev/null 2>&1 ;;
  p437) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test315.inc > ../outputs/t437
    exec diff ../outputs/t437 ../golden/t437 >/dev/null 2>&1 ;;
  p438) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test316.inc > ../outputs/t438
    exec diff ../outputs/t438 ../golden/t438 >/dev/null 2>&1 ;;
  p439) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test317.inc > ../outputs/t439
    exec diff ../outputs/t439 ../golden/t439 >/dev/null 2>&1 ;;
  p440) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test318.inc > ../outputs/t440
    exec diff ../outputs/t440 ../golden/t440 >/dev/null 2>&1 ;;
  p441) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test319.inc > ../outputs/t441
    exec diff ../outputs/t441 ../golden/t441 >/dev/null 2>&1 ;;
  p442) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test320.inc > ../outputs/t442
    exec diff ../outputs/t442 ../golden/t442 >/dev/null 2>&1 ;;
  p443) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test321.inc > ../outputs/t443
    exec diff ../outputs/t443 ../golden/t443 >/dev/null 2>&1 ;;
  p444) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test322.inc > ../outputs/t444
    exec diff ../outputs/t444 ../golden/t444 >/dev/null 2>&1 ;;
  p445) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test323.inc > ../outputs/t445
    exec diff ../outputs/t445 ../golden/t445 >/dev/null 2>&1 ;;
  p446) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test324.inc > ../outputs/t446
    exec diff ../outputs/t446 ../golden/t446 >/dev/null 2>&1 ;;
  p447) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test325.inc > ../outputs/t447
    exec diff ../outputs/t447 ../golden/t447 >/dev/null 2>&1 ;;
  p448) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test326.inc > ../outputs/t448
    exec diff ../outputs/t448 ../golden/t448 >/dev/null 2>&1 ;;
  p449) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test327.inc > ../outputs/t449
    exec diff ../outputs/t449 ../golden/t449 >/dev/null 2>&1 ;;
  p450) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test328.inc > ../outputs/t450
    exec diff ../outputs/t450 ../golden/t450 >/dev/null 2>&1 ;;
  p451) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test329.inc > ../outputs/t451
    exec diff ../outputs/t451 ../golden/t451 >/dev/null 2>&1 ;;
  p452) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test331.inc > ../outputs/t452
    exec diff ../outputs/t452 ../golden/t452 >/dev/null 2>&1 ;;
  p453) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test332.inc > ../outputs/t453
    exec diff ../outputs/t453 ../golden/t453 >/dev/null 2>&1 ;;
  p454) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test333.inc > ../outputs/t454
    exec diff ../outputs/t454 ../golden/t454 >/dev/null 2>&1 ;;
  p455) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test334.inc > ../outputs/t455
    exec diff ../outputs/t455 ../golden/t455 >/dev/null 2>&1 ;;
  p456) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test335.inc > ../outputs/t456
    exec diff ../outputs/t456 ../golden/t456 >/dev/null 2>&1 ;;
  p457) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test336.inc > ../outputs/t457
    exec diff ../outputs/t457 ../golden/t457 >/dev/null 2>&1 ;;
  p458) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test337.inc > ../outputs/t458
    exec diff ../outputs/t458 ../golden/t458 >/dev/null 2>&1 ;;
  p459) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test338.inc > ../outputs/t459
    exec diff ../outputs/t459 ../golden/t459 >/dev/null 2>&1 ;;
  p460) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test339.inc > ../outputs/t460
    exec diff ../outputs/t460 ../golden/t460 >/dev/null 2>&1 ;;
  p461) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test340.inc > ../outputs/t461
    exec diff ../outputs/t461 ../golden/t461 >/dev/null 2>&1 ;;
  p462) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test341.inc > ../outputs/t462
    exec diff ../outputs/t462 ../golden/t462 >/dev/null 2>&1 ;;
  p463) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test342.inc > ../outputs/t463
    exec diff ../outputs/t463 ../golden/t463 >/dev/null 2>&1 ;;
  p464) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test343.inc > ../outputs/t464
    exec diff ../outputs/t464 ../golden/t464 >/dev/null 2>&1 ;;
  p465) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test344.inc > ../outputs/t465
    exec diff ../outputs/t465 ../golden/t465 >/dev/null 2>&1 ;;
  p466) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test345.inc > ../outputs/t466
    exec diff ../outputs/t466 ../golden/t466 >/dev/null 2>&1 ;;
  p467) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test346.inc > ../outputs/t467
    exec diff ../outputs/t467 ../golden/t467 >/dev/null 2>&1 ;;
  p468) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test347.inc > ../outputs/t468
    exec diff ../outputs/t468 ../golden/t468 >/dev/null 2>&1 ;;
  p469) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test348.inc > ../outputs/t469
    exec diff ../outputs/t469 ../golden/t469 >/dev/null 2>&1 ;;
  p470) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test349.inc > ../outputs/t470
    exec diff ../outputs/t470 ../golden/t470 >/dev/null 2>&1 ;;
  p471) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test350.inc > ../outputs/t471
    exec diff ../outputs/t471 ../golden/t471 >/dev/null 2>&1 ;;
  p472) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test351.inc > ../outputs/t472
    exec diff ../outputs/t472 ../golden/t472 >/dev/null 2>&1 ;;
  p473) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test352.inc > ../outputs/t473
    exec diff ../outputs/t473 ../golden/t473 >/dev/null 2>&1 ;;
  p474) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test353.inc > ../outputs/t474
    exec diff ../outputs/t474 ../golden/t474 >/dev/null 2>&1 ;;
  p475) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test354.inc > ../outputs/t475
    exec diff ../outputs/t475 ../golden/t475 >/dev/null 2>&1 ;;
  p476) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test355.inc > ../outputs/t476
    exec diff ../outputs/t476 ../golden/t476 >/dev/null 2>&1 ;;
  p477) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test356.inc > ../outputs/t477
    exec diff ../outputs/t477 ../golden/t477 >/dev/null 2>&1 ;;
  p478) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test357.inc > ../outputs/t478
    exec diff ../outputs/t478 ../golden/t478 >/dev/null 2>&1 ;;
  p479) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test358.inc > ../outputs/t479
    exec diff ../outputs/t479 ../golden/t479 >/dev/null 2>&1 ;;
  p480) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test359.inc > ../outputs/t480
    exec diff ../outputs/t480 ../golden/t480 >/dev/null 2>&1 ;;
  p481) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test361.inc > ../outputs/t481
    exec diff ../outputs/t481 ../golden/t481 >/dev/null 2>&1 ;;
  p482) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test362.inc > ../outputs/t482
    exec diff ../outputs/t482 ../golden/t482 >/dev/null 2>&1 ;;
  p483) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test363.inc > ../outputs/t483
    exec diff ../outputs/t483 ../golden/t483 >/dev/null 2>&1 ;;
  p484) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test364.inc > ../outputs/t484
    exec diff ../outputs/t484 ../golden/t484 >/dev/null 2>&1 ;;
  p485) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test365.inc > ../outputs/t485
    exec diff ../outputs/t485 ../golden/t485 >/dev/null 2>&1 ;;
  p486) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test366.inc > ../outputs/t486
    exec diff ../outputs/t486 ../golden/t486 >/dev/null 2>&1 ;;
  p487) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test367.inc > ../outputs/t487
    exec diff ../outputs/t487 ../golden/t487 >/dev/null 2>&1 ;;
  p488) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test368.inc > ../outputs/t488
    exec diff ../outputs/t488 ../golden/t488 >/dev/null 2>&1 ;;
  p489) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test369.inc > ../outputs/t489
    exec diff ../outputs/t489 ../golden/t489 >/dev/null 2>&1 ;;
  p490) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test370.inc > ../outputs/t490
    exec diff ../outputs/t490 ../golden/t490 >/dev/null 2>&1 ;;
  p491) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test371.inc > ../outputs/t491
    exec diff ../outputs/t491 ../golden/t491 >/dev/null 2>&1 ;;
  p492) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test372.inc > ../outputs/t492
    exec diff ../outputs/t492 ../golden/t492 >/dev/null 2>&1 ;;
  p493) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test373.inc > ../outputs/t493
    exec diff ../outputs/t493 ../golden/t493 >/dev/null 2>&1 ;;
  p494) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test374.inc > ../outputs/t494
    exec diff ../outputs/t494 ../golden/t494 >/dev/null 2>&1 ;;
  p495) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test375.inc > ../outputs/t495
    exec diff ../outputs/t495 ../golden/t495 >/dev/null 2>&1 ;;
  p496) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test376.inc > ../outputs/t496
    exec diff ../outputs/t496 ../golden/t496 >/dev/null 2>&1 ;;
  p497) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test377.inc > ../outputs/t497
    exec diff ../outputs/t497 ../golden/t497 >/dev/null 2>&1 ;;
  p498) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test378.inc > ../outputs/t498
    exec diff ../outputs/t498 ../golden/t498 >/dev/null 2>&1 ;;
  p499) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test379.inc > ../outputs/t499
    exec diff ../outputs/t499 ../golden/t499 >/dev/null 2>&1 ;;
  p500) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test380.inc > ../outputs/t500
    exec diff ../outputs/t500 ../golden/t500 >/dev/null 2>&1 ;;
  p501) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test381.inc > ../outputs/t501
    exec diff ../outputs/t501 ../golden/t501 >/dev/null 2>&1 ;;
  p502) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test382.inc > ../outputs/t502
    exec diff ../outputs/t502 ../golden/t502 >/dev/null 2>&1 ;;
  p503) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test383.inc > ../outputs/t503
    exec diff ../outputs/t503 ../golden/t503 >/dev/null 2>&1 ;;
  p504) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test384.inc > ../outputs/t504
    exec diff ../outputs/t504 ../golden/t504 >/dev/null 2>&1 ;;
  p505) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test385.inc > ../outputs/t505
    exec diff ../outputs/t505 ../golden/t505 >/dev/null 2>&1 ;;
  p506) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test386.inc > ../outputs/t506
    exec diff ../outputs/t506 ../golden/t506 >/dev/null 2>&1 ;;
  p507) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test387.inc > ../outputs/t507
    exec diff ../outputs/t507 ../golden/t507 >/dev/null 2>&1 ;;
  p508) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test388.inc > ../outputs/t508
    exec diff ../outputs/t508 ../golden/t508 >/dev/null 2>&1 ;;
  p509) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test390.inc > ../outputs/t509
    exec diff ../outputs/t509 ../golden/t509 >/dev/null 2>&1 ;;
  p510) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test391.inc > ../outputs/t510
    exec diff ../outputs/t510 ../golden/t510 >/dev/null 2>&1 ;;
  p511) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test392.inc > ../outputs/t511
    exec diff ../outputs/t511 ../golden/t511 >/dev/null 2>&1 ;;
  p512) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test393.inc > ../outputs/t512
    exec diff ../outputs/t512 ../golden/t512 >/dev/null 2>&1 ;;
  p513) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test394.inc > ../outputs/t513
    exec diff ../outputs/t513 ../golden/t513 >/dev/null 2>&1 ;;
  p514) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test395.inc > ../outputs/t514
    exec diff ../outputs/t514 ../golden/t514 >/dev/null 2>&1 ;;
  p515) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test396.inc > ../outputs/t515
    exec diff ../outputs/t515 ../golden/t515 >/dev/null 2>&1 ;;
  p516) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test397.inc > ../outputs/t516
    exec diff ../outputs/t516 ../golden/t516 >/dev/null 2>&1 ;;
  p517) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test398.inc > ../outputs/t517
    exec diff ../outputs/t517 ../golden/t517 >/dev/null 2>&1 ;;
  p518) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test399.inc > ../outputs/t518
    exec diff ../outputs/t518 ../golden/t518 >/dev/null 2>&1 ;;
  p519) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test400.inc > ../outputs/t519
    exec diff ../outputs/t519 ../golden/t519 >/dev/null 2>&1 ;;
  p520) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test401.inc > ../outputs/t520
    exec diff ../outputs/t520 ../golden/t520 >/dev/null 2>&1 ;;
  p521) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test402.inc > ../outputs/t521
    exec diff ../outputs/t521 ../golden/t521 >/dev/null 2>&1 ;;
  p522) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test403.inc > ../outputs/t522
    exec diff ../outputs/t522 ../golden/t522 >/dev/null 2>&1 ;;
  p523) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test404.inc > ../outputs/t523
    exec diff ../outputs/t523 ../golden/t523 >/dev/null 2>&1 ;;
  p524) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test405.inc > ../outputs/t524
    exec diff ../outputs/t524 ../golden/t524 >/dev/null 2>&1 ;;
  p525) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test406.inc > ../outputs/t525
    exec diff ../outputs/t525 ../golden/t525 >/dev/null 2>&1 ;;
  p526) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test407.inc > ../outputs/t526
    exec diff ../outputs/t526 ../golden/t526 >/dev/null 2>&1 ;;
  p527) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test408.inc > ../outputs/t527
    exec diff ../outputs/t527 ../golden/t527 >/dev/null 2>&1 ;;
  p528) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test409.inc > ../outputs/t528
    exec diff ../outputs/t528 ../golden/t528 >/dev/null 2>&1 ;;
  p529) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/test410.inc > ../outputs/t529
    exec diff ../outputs/t529 ../golden/t529 >/dev/null 2>&1 ;;
  p530) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst21.mat > ../outputs/t530
    exec diff ../outputs/t530 ../golden/t530 >/dev/null 2>&1 ;;
  p531) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst22.mat > ../outputs/t531
    exec diff ../outputs/t531 ../golden/t531 >/dev/null 2>&1 ;;
  p532) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst23.mat > ../outputs/t532
    exec diff ../outputs/t532 ../golden/t532 >/dev/null 2>&1 ;;
  p533) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst24.mat > ../outputs/t533
    exec diff ../outputs/t533 ../golden/t533 >/dev/null 2>&1 ;;
  p534) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst25.mat > ../outputs/t534
    exec diff ../outputs/t534 ../golden/t534 >/dev/null 2>&1 ;;
  p535) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst26.mat > ../outputs/t535
    exec diff ../outputs/t535 ../golden/t535 >/dev/null 2>&1 ;;
  p536) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst27.mat > ../outputs/t536
    exec diff ../outputs/t536 ../golden/t536 >/dev/null 2>&1 ;;
  p537) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst28.mat > ../outputs/t537
    exec diff ../outputs/t537 ../golden/t537 >/dev/null 2>&1 ;;
  p538) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2question.mat > ../outputs/t538
    exec diff ../outputs/t538 ../golden/t538 >/dev/null 2>&1 ;;
  p539) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2rtangle.mat > ../outputs/t539
    exec diff ../outputs/t539 ../golden/t539 >/dev/null 2>&1 ;;
  p540) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2=.mat > ../outputs/t540
    exec diff ../outputs/t540 ../golden/t540 >/dev/null 2>&1 ;;
  p541) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2:.mat > ../outputs/t541
    exec diff ../outputs/t541 ../golden/t541 >/dev/null 2>&1 ;;
  p542) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2g.mat > ../outputs/t542
    exec diff ../outputs/t542 ../golden/t542 >/dev/null 2>&1 ;;
  p543) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2@.mat > ../outputs/t543
    exec diff ../outputs/t543 ../golden/t543 >/dev/null 2>&1 ;;
  p544) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2A.mat > ../outputs/t544
    exec diff ../outputs/t544 ../golden/t544 >/dev/null 2>&1 ;;
  p545) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2B.mat > ../outputs/t545
    exec diff ../outputs/t545 ../golden/t545 >/dev/null 2>&1 ;;
  p546) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2D.mat > ../outputs/t546
    exec diff ../outputs/t546 ../golden/t546 >/dev/null 2>&1 ;;
  p547) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2E.mat > ../outputs/t547
    exec diff ../outputs/t547 ../golden/t547 >/dev/null 2>&1 ;;
  p548) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2f.mat > ../outputs/t548
    exec diff ../outputs/t548 ../golden/t548 >/dev/null 2>&1 ;;
  p549) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/tst2D.mat > ../outputs/t549
    exec diff ../outputs/t549 ../golden/t549 >/dev/null 2>&1 ;;
  p550) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAA.mat > ../outputs/t550
    exec diff ../outputs/t550 ../golden/t550 >/dev/null 2>&1 ;;
  p551) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAB.mat > ../outputs/t551
    exec diff ../outputs/t551 ../golden/t551 >/dev/null 2>&1 ;;
  p552) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAC.mat > ../outputs/t552
    exec diff ../outputs/t552 ../golden/t552 >/dev/null 2>&1 ;;
  p553) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAD.mat > ../outputs/t553
    exec diff ../outputs/t553 ../golden/t553 >/dev/null 2>&1 ;;
  p554) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAE.mat > ../outputs/t554
    exec diff ../outputs/t554 ../golden/t554 >/dev/null 2>&1 ;;
  p555) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAF.mat > ../outputs/t555
    exec diff ../outputs/t555 ../golden/t555 >/dev/null 2>&1 ;;
  p556) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAG.mat > ../outputs/t556
    exec diff ../outputs/t556 ../golden/t556 >/dev/null 2>&1 ;;
  p557) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAH.mat > ../outputs/t557
    exec diff ../outputs/t557 ../golden/t557 >/dev/null 2>&1 ;;
  p558) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAI.mat > ../outputs/t558
    exec diff ../outputs/t558 ../golden/t558 >/dev/null 2>&1 ;;
  p559) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAJ.mat > ../outputs/t559
    exec diff ../outputs/t559 ../golden/t559 >/dev/null 2>&1 ;;
  p560) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFa.mat > ../outputs/t560
    exec diff ../outputs/t560 ../golden/t560 >/dev/null 2>&1 ;;
  p561) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFb.mat > ../outputs/t561
    exec diff ../outputs/t561 ../golden/t561 >/dev/null 2>&1 ;;
  p562) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFc.mat > ../outputs/t562
    exec diff ../outputs/t562 ../golden/t562 >/dev/null 2>&1 ;;
  p563) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFd.mat > ../outputs/t563
    exec diff ../outputs/t563 ../golden/t563 >/dev/null 2>&1 ;;
  p564) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFe.mat > ../outputs/t564
    exec diff ../outputs/t564 ../golden/t564 >/dev/null 2>&1 ;;
  p565) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFf.mat > ../outputs/t565
    exec diff ../outputs/t565 ../golden/t565 >/dev/null 2>&1 ;;
  p566) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFg.mat > ../outputs/t566
    exec diff ../outputs/t566 ../golden/t566 >/dev/null 2>&1 ;;
  p567) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFh.mat > ../outputs/t567
    exec diff ../outputs/t567 ../golden/t567 >/dev/null 2>&1 ;;
  p568) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFi.mat > ../outputs/t568
    exec diff ../outputs/t568 ../golden/t568 >/dev/null 2>&1 ;;
  p569) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEI.mat > ../outputs/t569
    exec diff ../outputs/t569 ../golden/t569 >/dev/null 2>&1 ;;
  p570) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEJ.mat > ../outputs/t570
    exec diff ../outputs/t570 ../golden/t570 >/dev/null 2>&1 ;;
  p571) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEK.mat > ../outputs/t571
    exec diff ../outputs/t571 ../golden/t571 >/dev/null 2>&1 ;;
  p572) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEL.mat > ../outputs/t572
    exec diff ../outputs/t572 ../golden/t572 >/dev/null 2>&1 ;;
  p573) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEM.mat > ../outputs/t573
    exec diff ../outputs/t573 ../golden/t573 >/dev/null 2>&1 ;;
  p574) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEN.mat > ../outputs/t574
    exec diff ../outputs/t574 ../golden/t574 >/dev/null 2>&1 ;;
  p575) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEO.mat > ../outputs/t575
    exec diff ../outputs/t575 ../golden/t575 >/dev/null 2>&1 ;;
  p576) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEP.mat > ../outputs/t576
    exec diff ../outputs/t576 ../golden/t576 >/dev/null 2>&1 ;;
  p577) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEQ.mat > ../outputs/t577
    exec diff ../outputs/t577 ../golden/t577 >/dev/null 2>&1 ;;
  p578) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAER.mat > ../outputs/t578
    exec diff ../outputs/t578 ../golden/t578 >/dev/null 2>&1 ;;
  p579) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAES.mat > ../outputs/t579
    exec diff ../outputs/t579 ../golden/t579 >/dev/null 2>&1 ;;
  p580) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAET.mat > ../outputs/t580
    exec diff ../outputs/t580 ../golden/t580 >/dev/null 2>&1 ;;
  p581) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEU.mat > ../outputs/t581
    exec diff ../outputs/t581 ../golden/t581 >/dev/null 2>&1 ;;
  p582) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEV.mat > ../outputs/t582
    exec diff ../outputs/t582 ../golden/t582 >/dev/null 2>&1 ;;
  p583) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEW.mat > ../outputs/t583
    exec diff ../outputs/t583 ../golden/t583 >/dev/null 2>&1 ;;
  p584) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEX.mat > ../outputs/t584
    exec diff ../outputs/t584 ../golden/t584 >/dev/null 2>&1 ;;
  p585) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEY.mat > ../outputs/t585
    exec diff ../outputs/t585 ../golden/t585 >/dev/null 2>&1 ;;
  p586) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEZ.mat > ../outputs/t586
    exec diff ../outputs/t586 ../golden/t586 >/dev/null 2>&1 ;;
  p587) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAE[.mat > ../outputs/t587
    exec diff ../outputs/t587 ../golden/t587 >/dev/null 2>&1 ;;
  p588) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAE].mat > ../outputs/t588
    exec diff ../outputs/t588 ../golden/t588 >/dev/null 2>&1 ;;
  p589) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAE_.mat > ../outputs/t589
    exec diff ../outputs/t589 ../golden/t589 >/dev/null 2>&1 ;;
  p590) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEa.mat > ../outputs/t590
    exec diff ../outputs/t590 ../golden/t590 >/dev/null 2>&1 ;;
  p591) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEb.mat > ../outputs/t591
    exec diff ../outputs/t591 ../golden/t591 >/dev/null 2>&1 ;;
  p592) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEc.mat > ../outputs/t592
    exec diff ../outputs/t592 ../golden/t592 >/dev/null 2>&1 ;;
  p593) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEd.mat > ../outputs/t593
    exec diff ../outputs/t593 ../golden/t593 >/dev/null 2>&1 ;;
  p594) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEe.mat > ../outputs/t594
    exec diff ../outputs/t594 ../golden/t594 >/dev/null 2>&1 ;;
  p595) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEf.mat > ../outputs/t595
    exec diff ../outputs/t595 ../golden/t595 >/dev/null 2>&1 ;;
  p596) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEg.mat > ../outputs/t596
    exec diff ../outputs/t596 ../golden/t596 >/dev/null 2>&1 ;;
  p597) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEh.mat > ../outputs/t597
    exec diff ../outputs/t597 ../golden/t597 >/dev/null 2>&1 ;;
  p598) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEi.mat > ../outputs/t598
    exec diff ../outputs/t598 ../golden/t598 >/dev/null 2>&1 ;;
  p599) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEj.mat > ../outputs/t599
    exec diff ../outputs/t599 ../golden/t599 >/dev/null 2>&1 ;;
  p600) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEk.mat > ../outputs/t600
    exec diff ../outputs/t600 ../golden/t600 >/dev/null 2>&1 ;;
  p601) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEl.mat > ../outputs/t601
    exec diff ../outputs/t601 ../golden/t601 >/dev/null 2>&1 ;;
  p602) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEm.mat > ../outputs/t602
    exec diff ../outputs/t602 ../golden/t602 >/dev/null 2>&1 ;;
  p603) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEn.mat > ../outputs/t603
    exec diff ../outputs/t603 ../golden/t603 >/dev/null 2>&1 ;;
  p604) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEo.mat > ../outputs/t604
    exec diff ../outputs/t604 ../golden/t604 >/dev/null 2>&1 ;;
  p605) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEp.mat > ../outputs/t605
    exec diff ../outputs/t605 ../golden/t605 >/dev/null 2>&1 ;;
  p606) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEq.mat > ../outputs/t606
    exec diff ../outputs/t606 ../golden/t606 >/dev/null 2>&1 ;;
  p607) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEr.mat > ../outputs/t607
    exec diff ../outputs/t607 ../golden/t607 >/dev/null 2>&1 ;;
  p608) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEs.mat > ../outputs/t608
    exec diff ../outputs/t608 ../golden/t608 >/dev/null 2>&1 ;;
  p609) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEt.mat > ../outputs/t609
    exec diff ../outputs/t609 ../golden/t609 >/dev/null 2>&1 ;;
  p610) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEu.mat > ../outputs/t610
    exec diff ../outputs/t610 ../golden/t610 >/dev/null 2>&1 ;;
  p611) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEv.mat > ../outputs/t611
    exec diff ../outputs/t611 ../golden/t611 >/dev/null 2>&1 ;;
  p612) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEw.mat > ../outputs/t612
    exec diff ../outputs/t612 ../golden/t612 >/dev/null 2>&1 ;;
  p613) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEx.mat > ../outputs/t613
    exec diff ../outputs/t613 ../golden/t613 >/dev/null 2>&1 ;;
  p614) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEy.mat > ../outputs/t614
    exec diff ../outputs/t614 ../golden/t614 >/dev/null 2>&1 ;;
  p615) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFA.mat > ../outputs/t615
    exec diff ../outputs/t615 ../golden/t615 >/dev/null 2>&1 ;;
  p616) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFB.mat > ../outputs/t616
    exec diff ../outputs/t616 ../golden/t616 >/dev/null 2>&1 ;;
  p617) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFC.mat > ../outputs/t617
    exec diff ../outputs/t617 ../golden/t617 >/dev/null 2>&1 ;;
  p618) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFD.mat > ../outputs/t618
    exec diff ../outputs/t618 ../golden/t618 >/dev/null 2>&1 ;;
  p619) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFE.mat > ../outputs/t619
    exec diff ../outputs/t619 ../golden/t619 >/dev/null 2>&1 ;;
  p620) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFF.mat > ../outputs/t620
    exec diff ../outputs/t620 ../golden/t620 >/dev/null 2>&1 ;;
  p621) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFG.mat > ../outputs/t621
    exec diff ../outputs/t621 ../golden/t621 >/dev/null 2>&1 ;;
  p622) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFH.mat > ../outputs/t622
    exec diff ../outputs/t622 ../golden/t622 >/dev/null 2>&1 ;;
  p623) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFI.mat > ../outputs/t623
    exec diff ../outputs/t623 ../golden/t623 >/dev/null 2>&1 ;;
  p624) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFJ.mat > ../outputs/t624
    exec diff ../outputs/t624 ../golden/t624 >/dev/null 2>&1 ;;
  p625) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFK.mat > ../outputs/t625
    exec diff ../outputs/t625 ../golden/t625 >/dev/null 2>&1 ;;
  p626) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFL.mat > ../outputs/t626
    exec diff ../outputs/t626 ../golden/t626 >/dev/null 2>&1 ;;
  p627) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFM.mat > ../outputs/t627
    exec diff ../outputs/t627 ../golden/t627 >/dev/null 2>&1 ;;
  p628) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFN.mat > ../outputs/t628
    exec diff ../outputs/t628 ../golden/t628 >/dev/null 2>&1 ;;
  p629) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFO.mat > ../outputs/t629
    exec diff ../outputs/t629 ../golden/t629 >/dev/null 2>&1 ;;
  p630) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFP.mat > ../outputs/t630
    exec diff ../outputs/t630 ../golden/t630 >/dev/null 2>&1 ;;
  p631) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFQ.mat > ../outputs/t631
    exec diff ../outputs/t631 ../golden/t631 >/dev/null 2>&1 ;;
  p632) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFR.mat > ../outputs/t632
    exec diff ../outputs/t632 ../golden/t632 >/dev/null 2>&1 ;;
  p633) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFS.mat > ../outputs/t633
    exec diff ../outputs/t633 ../golden/t633 >/dev/null 2>&1 ;;
  p634) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFT.mat > ../outputs/t634
    exec diff ../outputs/t634 ../golden/t634 >/dev/null 2>&1 ;;
  p635) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFU.mat > ../outputs/t635
    exec diff ../outputs/t635 ../golden/t635 >/dev/null 2>&1 ;;
  p636) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFV.mat > ../outputs/t636
    exec diff ../outputs/t636 ../golden/t636 >/dev/null 2>&1 ;;
  p637) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFW.mat > ../outputs/t637
    exec diff ../outputs/t637 ../golden/t637 >/dev/null 2>&1 ;;
  p638) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFX.mat > ../outputs/t638
    exec diff ../outputs/t638 ../golden/t638 >/dev/null 2>&1 ;;
  p639) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFY.mat > ../outputs/t639
    exec diff ../outputs/t639 ../golden/t639 >/dev/null 2>&1 ;;
  p640) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFZ.mat > ../outputs/t640
    exec diff ../outputs/t640 ../golden/t640 >/dev/null 2>&1 ;;
  p641) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAF[.mat > ../outputs/t641
    exec diff ../outputs/t641 ../golden/t641 >/dev/null 2>&1 ;;
  p642) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAF].mat > ../outputs/t642
    exec diff ../outputs/t642 ../golden/t642 >/dev/null 2>&1 ;;
  p643) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFhh.mat > ../outputs/t643
    exec diff ../outputs/t643 ../golden/t643 >/dev/null 2>&1 ;;
  p644) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAF_.mat > ../outputs/t644
    exec diff ../outputs/t644 ../golden/t644 >/dev/null 2>&1 ;;
  p645) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACk.mat > ../outputs/t645
    exec diff ../outputs/t645 ../golden/t645 >/dev/null 2>&1 ;;
  p646) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACl.mat > ../outputs/t646
    exec diff ../outputs/t646 ../golden/t646 >/dev/null 2>&1 ;;
  p647) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACm.mat > ../outputs/t647
    exec diff ../outputs/t647 ../golden/t647 >/dev/null 2>&1 ;;
  p648) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACn.mat > ../outputs/t648
    exec diff ../outputs/t648 ../golden/t648 >/dev/null 2>&1 ;;
  p649) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACo.mat > ../outputs/t649
    exec diff ../outputs/t649 ../golden/t649 >/dev/null 2>&1 ;;
  p650) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACp.mat > ../outputs/t650
    exec diff ../outputs/t650 ../golden/t650 >/dev/null 2>&1 ;;
  p651) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACq.mat > ../outputs/t651
    exec diff ../outputs/t651 ../golden/t651 >/dev/null 2>&1 ;;
  p652) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACr.mat > ../outputs/t652
    exec diff ../outputs/t652 ../golden/t652 >/dev/null 2>&1 ;;
  p653) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACs.mat > ../outputs/t653
    exec diff ../outputs/t653 ../golden/t653 >/dev/null 2>&1 ;;
  p654) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACt.mat > ../outputs/t654
    exec diff ../outputs/t654 ../golden/t654 >/dev/null 2>&1 ;;
  p655) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACu.mat > ../outputs/t655
    exec diff ../outputs/t655 ../golden/t655 >/dev/null 2>&1 ;;
  p656) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACv.mat > ../outputs/t656
    exec diff ../outputs/t656 ../golden/t656 >/dev/null 2>&1 ;;
  p657) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACw.mat > ../outputs/t657
    exec diff ../outputs/t657 ../golden/t657 >/dev/null 2>&1 ;;
  p658) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACx.mat > ../outputs/t658
    exec diff ../outputs/t658 ../golden/t658 >/dev/null 2>&1 ;;
  p659) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACy.mat > ../outputs/t659
    exec diff ../outputs/t659 ../golden/t659 >/dev/null 2>&1 ;;
  p660) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADA.mat > ../outputs/t660
    exec diff ../outputs/t660 ../golden/t660 >/dev/null 2>&1 ;;
  p661) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADB.mat > ../outputs/t661
    exec diff ../outputs/t661 ../golden/t661 >/dev/null 2>&1 ;;
  p662) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADC.mat > ../outputs/t662
    exec diff ../outputs/t662 ../golden/t662 >/dev/null 2>&1 ;;
  p663) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADD.mat > ../outputs/t663
    exec diff ../outputs/t663 ../golden/t663 >/dev/null 2>&1 ;;
  p664) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADE.mat > ../outputs/t664
    exec diff ../outputs/t664 ../golden/t664 >/dev/null 2>&1 ;;
  p665) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADF.mat > ../outputs/t665
    exec diff ../outputs/t665 ../golden/t665 >/dev/null 2>&1 ;;
  p666) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADG.mat > ../outputs/t666
    exec diff ../outputs/t666 ../golden/t666 >/dev/null 2>&1 ;;
  p667) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADH.mat > ../outputs/t667
    exec diff ../outputs/t667 ../golden/t667 >/dev/null 2>&1 ;;
  p668) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADI.mat > ../outputs/t668
    exec diff ../outputs/t668 ../golden/t668 >/dev/null 2>&1 ;;
  p669) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADJ.mat > ../outputs/t669
    exec diff ../outputs/t669 ../golden/t669 >/dev/null 2>&1 ;;
  p670) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADK.mat > ../outputs/t670
    exec diff ../outputs/t670 ../golden/t670 >/dev/null 2>&1 ;;
  p671) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADL.mat > ../outputs/t671
    exec diff ../outputs/t671 ../golden/t671 >/dev/null 2>&1 ;;
  p672) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADM.mat > ../outputs/t672
    exec diff ../outputs/t672 ../golden/t672 >/dev/null 2>&1 ;;
  p673) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADN.mat > ../outputs/t673
    exec diff ../outputs/t673 ../golden/t673 >/dev/null 2>&1 ;;
  p674) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADO.mat > ../outputs/t674
    exec diff ../outputs/t674 ../golden/t674 >/dev/null 2>&1 ;;
  p675) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADP.mat > ../outputs/t675
    exec diff ../outputs/t675 ../golden/t675 >/dev/null 2>&1 ;;
  p676) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADQ.mat > ../outputs/t676
    exec diff ../outputs/t676 ../golden/t676 >/dev/null 2>&1 ;;
  p677) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADR.mat > ../outputs/t677
    exec diff ../outputs/t677 ../golden/t677 >/dev/null 2>&1 ;;
  p678) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADS.mat > ../outputs/t678
    exec diff ../outputs/t678 ../golden/t678 >/dev/null 2>&1 ;;
  p679) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADT.mat > ../outputs/t679
    exec diff ../outputs/t679 ../golden/t679 >/dev/null 2>&1 ;;
  p680) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADU.mat > ../outputs/t680
    exec diff ../outputs/t680 ../golden/t680 >/dev/null 2>&1 ;;
  p681) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADV.mat > ../outputs/t681
    exec diff ../outputs/t681 ../golden/t681 >/dev/null 2>&1 ;;
  p682) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADW.mat > ../outputs/t682
    exec diff ../outputs/t682 ../golden/t682 >/dev/null 2>&1 ;;
  p683) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADX.mat > ../outputs/t683
    exec diff ../outputs/t683 ../golden/t683 >/dev/null 2>&1 ;;
  p684) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADY.mat > ../outputs/t684
    exec diff ../outputs/t684 ../golden/t684 >/dev/null 2>&1 ;;
  p685) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADZ.mat > ../outputs/t685
    exec diff ../outputs/t685 ../golden/t685 >/dev/null 2>&1 ;;
  p686) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAD[.mat > ../outputs/t686
    exec diff ../outputs/t686 ../golden/t686 >/dev/null 2>&1 ;;
  p687) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAD].mat > ../outputs/t687
    exec diff ../outputs/t687 ../golden/t687 >/dev/null 2>&1 ;;
  p688) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADhh.mat > ../outputs/t688
    exec diff ../outputs/t688 ../golden/t688 >/dev/null 2>&1 ;;
  p689) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAD_.mat > ../outputs/t689
    exec diff ../outputs/t689 ../golden/t689 >/dev/null 2>&1 ;;
  p690) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADa.mat > ../outputs/t690
    exec diff ../outputs/t690 ../golden/t690 >/dev/null 2>&1 ;;
  p691) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADb.mat > ../outputs/t691
    exec diff ../outputs/t691 ../golden/t691 >/dev/null 2>&1 ;;
  p692) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFi.mat > ../outputs/t692
    exec diff ../outputs/t692 ../golden/t692 >/dev/null 2>&1 ;;
  p693) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADd.mat > ../outputs/t693
    exec diff ../outputs/t693 ../golden/t693 >/dev/null 2>&1 ;;
  p694) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADe.mat > ../outputs/t694
    exec diff ../outputs/t694 ../golden/t694 >/dev/null 2>&1 ;;
  p695) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADf.mat > ../outputs/t695
    exec diff ../outputs/t695 ../golden/t695 >/dev/null 2>&1 ;;
  p696) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADg.mat > ../outputs/t696
    exec diff ../outputs/t696 ../golden/t696 >/dev/null 2>&1 ;;
  p697) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADh.mat > ../outputs/t697
    exec diff ../outputs/t697 ../golden/t697 >/dev/null 2>&1 ;;
  p698) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADi.mat > ../outputs/t698
    exec diff ../outputs/t698 ../golden/t698 >/dev/null 2>&1 ;;
  p699) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADj.mat > ../outputs/t699
    exec diff ../outputs/t699 ../golden/t699 >/dev/null 2>&1 ;;
  p700) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADk.mat > ../outputs/t700
    exec diff ../outputs/t700 ../golden/t700 >/dev/null 2>&1 ;;
  p701) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADl.mat > ../outputs/t701
    exec diff ../outputs/t701 ../golden/t701 >/dev/null 2>&1 ;;
  p702) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADm.mat > ../outputs/t702
    exec diff ../outputs/t702 ../golden/t702 >/dev/null 2>&1 ;;
  p703) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADn.mat > ../outputs/t703
    exec diff ../outputs/t703 ../golden/t703 >/dev/null 2>&1 ;;
  p704) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADo.mat > ../outputs/t704
    exec diff ../outputs/t704 ../golden/t704 >/dev/null 2>&1 ;;
  p705) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADp.mat > ../outputs/t705
    exec diff ../outputs/t705 ../golden/t705 >/dev/null 2>&1 ;;
  p706) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADq.mat > ../outputs/t706
    exec diff ../outputs/t706 ../golden/t706 >/dev/null 2>&1 ;;
  p707) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADr.mat > ../outputs/t707
    exec diff ../outputs/t707 ../golden/t707 >/dev/null 2>&1 ;;
  p708) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADs.mat > ../outputs/t708
    exec diff ../outputs/t708 ../golden/t708 >/dev/null 2>&1 ;;
  p709) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADt.mat > ../outputs/t709
    exec diff ../outputs/t709 ../golden/t709 >/dev/null 2>&1 ;;
  p710) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADu.mat > ../outputs/t710
    exec diff ../outputs/t710 ../golden/t710 >/dev/null 2>&1 ;;
  p711) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADv.mat > ../outputs/t711
    exec diff ../outputs/t711 ../golden/t711 >/dev/null 2>&1 ;;
  p712) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADw.mat > ../outputs/t712
    exec diff ../outputs/t712 ../golden/t712 >/dev/null 2>&1 ;;
  p713) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADx.mat > ../outputs/t713
    exec diff ../outputs/t713 ../golden/t713 >/dev/null 2>&1 ;;
  p714) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkADy.mat > ../outputs/t714
    exec diff ../outputs/t714 ../golden/t714 >/dev/null 2>&1 ;;
  p715) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEA.mat > ../outputs/t715
    exec diff ../outputs/t715 ../golden/t715 >/dev/null 2>&1 ;;
  p716) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEB.mat > ../outputs/t716
    exec diff ../outputs/t716 ../golden/t716 >/dev/null 2>&1 ;;
  p717) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEC.mat > ../outputs/t717
    exec diff ../outputs/t717 ../golden/t717 >/dev/null 2>&1 ;;
  p718) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAED.mat > ../outputs/t718
    exec diff ../outputs/t718 ../golden/t718 >/dev/null 2>&1 ;;
  p719) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEE.mat > ../outputs/t719
    exec diff ../outputs/t719 ../golden/t719 >/dev/null 2>&1 ;;
  p720) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEF.mat > ../outputs/t720
    exec diff ../outputs/t720 ../golden/t720 >/dev/null 2>&1 ;;
  p721) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEG.mat > ../outputs/t721
    exec diff ../outputs/t721 ../golden/t721 >/dev/null 2>&1 ;;
  p722) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAEH.mat > ../outputs/t722
    exec diff ../outputs/t722 ../golden/t722 >/dev/null 2>&1 ;;
  p723) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABT.mat > ../outputs/t723
    exec diff ../outputs/t723 ../golden/t723 >/dev/null 2>&1 ;;
  p724) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABU.mat > ../outputs/t724
    exec diff ../outputs/t724 ../golden/t724 >/dev/null 2>&1 ;;
  p725) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABV.mat > ../outputs/t725
    exec diff ../outputs/t725 ../golden/t725 >/dev/null 2>&1 ;;
  p726) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABW.mat > ../outputs/t726
    exec diff ../outputs/t726 ../golden/t726 >/dev/null 2>&1 ;;
  p727) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABX.mat > ../outputs/t727
    exec diff ../outputs/t727 ../golden/t727 >/dev/null 2>&1 ;;
  p728) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABY.mat > ../outputs/t728
    exec diff ../outputs/t728 ../golden/t728 >/dev/null 2>&1 ;;
  p729) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABZ.mat > ../outputs/t729
    exec diff ../outputs/t729 ../golden/t729 >/dev/null 2>&1 ;;
  p730) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAB[.mat > ../outputs/t730
    exec diff ../outputs/t730 ../golden/t730 >/dev/null 2>&1 ;;
  p731) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAB].mat > ../outputs/t731
    exec diff ../outputs/t731 ../golden/t731 >/dev/null 2>&1 ;;
  p732) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAB_.mat > ../outputs/t732
    exec diff ../outputs/t732 ../golden/t732 >/dev/null 2>&1 ;;
  p733) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABa.mat > ../outputs/t733
    exec diff ../outputs/t733 ../golden/t733 >/dev/null 2>&1 ;;
  p734) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABb.mat > ../outputs/t734
    exec diff ../outputs/t734 ../golden/t734 >/dev/null 2>&1 ;;
  p735) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABc.mat > ../outputs/t735
    exec diff ../outputs/t735 ../golden/t735 >/dev/null 2>&1 ;;
  p736) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABd.mat > ../outputs/t736
    exec diff ../outputs/t736 ../golden/t736 >/dev/null 2>&1 ;;
  p737) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABe.mat > ../outputs/t737
    exec diff ../outputs/t737 ../golden/t737 >/dev/null 2>&1 ;;
  p738) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABf.mat > ../outputs/t738
    exec diff ../outputs/t738 ../golden/t738 >/dev/null 2>&1 ;;
  p739) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABg.mat > ../outputs/t739
    exec diff ../outputs/t739 ../golden/t739 >/dev/null 2>&1 ;;
  p740) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAB_.mat > ../outputs/t740
    exec diff ../outputs/t740 ../golden/t740 >/dev/null 2>&1 ;;
  p741) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABa.mat > ../outputs/t741
    exec diff ../outputs/t741 ../golden/t741 >/dev/null 2>&1 ;;
  p742) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABb.mat > ../outputs/t742
    exec diff ../outputs/t742 ../golden/t742 >/dev/null 2>&1 ;;
  p743) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABc.mat > ../outputs/t743
    exec diff ../outputs/t743 ../golden/t743 >/dev/null 2>&1 ;;
  p744) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABd.mat > ../outputs/t744
    exec diff ../outputs/t744 ../golden/t744 >/dev/null 2>&1 ;;
  p745) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABe.mat > ../outputs/t745
    exec diff ../outputs/t745 ../golden/t745 >/dev/null 2>&1 ;;
  p746) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABf.mat > ../outputs/t746
    exec diff ../outputs/t746 ../golden/t746 >/dev/null 2>&1 ;;
  p747) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABg.mat > ../outputs/t747
    exec diff ../outputs/t747 ../golden/t747 >/dev/null 2>&1 ;;
  p748) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABh.mat > ../outputs/t748
    exec diff ../outputs/t748 ../golden/t748 >/dev/null 2>&1 ;;
  p749) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABi.mat > ../outputs/t749
    exec diff ../outputs/t749 ../golden/t749 >/dev/null 2>&1 ;;
  p750) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABj.mat > ../outputs/t750
    exec diff ../outputs/t750 ../golden/t750 >/dev/null 2>&1 ;;
  p751) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABk.mat > ../outputs/t751
    exec diff ../outputs/t751 ../golden/t751 >/dev/null 2>&1 ;;
  p752) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABl.mat > ../outputs/t752
    exec diff ../outputs/t752 ../golden/t752 >/dev/null 2>&1 ;;
  p753) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABm.mat > ../outputs/t753
    exec diff ../outputs/t753 ../golden/t753 >/dev/null 2>&1 ;;
  p754) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABn.mat > ../outputs/t754
    exec diff ../outputs/t754 ../golden/t754 >/dev/null 2>&1 ;;
  p755) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABo.mat > ../outputs/t755
    exec diff ../outputs/t755 ../golden/t755 >/dev/null 2>&1 ;;
  p756) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABp.mat > ../outputs/t756
    exec diff ../outputs/t756 ../golden/t756 >/dev/null 2>&1 ;;
  p757) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAFi.mat > ../outputs/t757
    exec diff ../outputs/t757 ../golden/t757 >/dev/null 2>&1 ;;
  p758) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACC.mat > ../outputs/t758
    exec diff ../outputs/t758 ../golden/t758 >/dev/null 2>&1 ;;
  p759) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACD.mat > ../outputs/t759
    exec diff ../outputs/t759 ../golden/t759 >/dev/null 2>&1 ;;
  p760) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACE.mat > ../outputs/t760
    exec diff ../outputs/t760 ../golden/t760 >/dev/null 2>&1 ;;
  p761) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACF.mat > ../outputs/t761
    exec diff ../outputs/t761 ../golden/t761 >/dev/null 2>&1 ;;
  p762) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACG.mat > ../outputs/t762
    exec diff ../outputs/t762 ../golden/t762 >/dev/null 2>&1 ;;
  p763) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACH.mat > ../outputs/t763
    exec diff ../outputs/t763 ../golden/t763 >/dev/null 2>&1 ;;
  p764) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACI.mat > ../outputs/t764
    exec diff ../outputs/t764 ../golden/t764 >/dev/null 2>&1 ;;
  p765) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACJ.mat > ../outputs/t765
    exec diff ../outputs/t765 ../golden/t765 >/dev/null 2>&1 ;;
  p766) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACK.mat > ../outputs/t766
    exec diff ../outputs/t766 ../golden/t766 >/dev/null 2>&1 ;;
  p767) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACL.mat > ../outputs/t767
    exec diff ../outputs/t767 ../golden/t767 >/dev/null 2>&1 ;;
  p768) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACM.mat > ../outputs/t768
    exec diff ../outputs/t768 ../golden/t768 >/dev/null 2>&1 ;;
  p769) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACN.mat > ../outputs/t769
    exec diff ../outputs/t769 ../golden/t769 >/dev/null 2>&1 ;;
  p770) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACO.mat > ../outputs/t770
    exec diff ../outputs/t770 ../golden/t770 >/dev/null 2>&1 ;;
  p771) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACP.mat > ../outputs/t771
    exec diff ../outputs/t771 ../golden/t771 >/dev/null 2>&1 ;;
  p772) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACQ.mat > ../outputs/t772
    exec diff ../outputs/t772 ../golden/t772 >/dev/null 2>&1 ;;
  p773) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACR.mat > ../outputs/t773
    exec diff ../outputs/t773 ../golden/t773 >/dev/null 2>&1 ;;
  p774) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACS.mat > ../outputs/t774
    exec diff ../outputs/t774 ../golden/t774 >/dev/null 2>&1 ;;
  p775) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACT.mat > ../outputs/t775
    exec diff ../outputs/t775 ../golden/t775 >/dev/null 2>&1 ;;
  p776) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACU.mat > ../outputs/t776
    exec diff ../outputs/t776 ../golden/t776 >/dev/null 2>&1 ;;
  p777) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACV.mat > ../outputs/t777
    exec diff ../outputs/t777 ../golden/t777 >/dev/null 2>&1 ;;
  p778) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACW.mat > ../outputs/t778
    exec diff ../outputs/t778 ../golden/t778 >/dev/null 2>&1 ;;
  p779) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACX.mat > ../outputs/t779
    exec diff ../outputs/t779 ../golden/t779 >/dev/null 2>&1 ;;
  p780) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACY.mat > ../outputs/t780
    exec diff ../outputs/t780 ../golden/t780 >/dev/null 2>&1 ;;
  p781) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACZ.mat > ../outputs/t781
    exec diff ../outputs/t781 ../golden/t781 >/dev/null 2>&1 ;;
  p782) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAC[.mat > ../outputs/t782
    exec diff ../outputs/t782 ../golden/t782 >/dev/null 2>&1 ;;
  p783) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAC].mat > ../outputs/t783
    exec diff ../outputs/t783 ../golden/t783 >/dev/null 2>&1 ;;
  p784) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAC_.mat > ../outputs/t784
    exec diff ../outputs/t784 ../golden/t784 >/dev/null 2>&1 ;;
  p785) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACa.mat > ../outputs/t785
    exec diff ../outputs/t785 ../golden/t785 >/dev/null 2>&1 ;;
  p786) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACb.mat > ../outputs/t786
    exec diff ../outputs/t786 ../golden/t786 >/dev/null 2>&1 ;;
  p787) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACc.mat > ../outputs/t787
    exec diff ../outputs/t787 ../golden/t787 >/dev/null 2>&1 ;;
  p788) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACd.mat > ../outputs/t788
    exec diff ../outputs/t788 ../golden/t788 >/dev/null 2>&1 ;;
  p789) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACe.mat > ../outputs/t789
    exec diff ../outputs/t789 ../golden/t789 >/dev/null 2>&1 ;;
  p790) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACf.mat > ../outputs/t790
    exec diff ../outputs/t790 ../golden/t790 >/dev/null 2>&1 ;;
  p791) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACg.mat > ../outputs/t791
    exec diff ../outputs/t791 ../golden/t791 >/dev/null 2>&1 ;;
  p792) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACh.mat > ../outputs/t792
    exec diff ../outputs/t792 ../golden/t792 >/dev/null 2>&1 ;;
  p793) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACi.mat > ../outputs/t793
    exec diff ../outputs/t793 ../golden/t793 >/dev/null 2>&1 ;;
  p794) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkACj.mat > ../outputs/t794
    exec diff ../outputs/t794 ../golden/t794 >/dev/null 2>&1 ;;
  p795) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAK.mat > ../outputs/t795
    exec diff ../outputs/t795 ../golden/t795 >/dev/null 2>&1 ;;
  p796) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAL.mat > ../outputs/t796
    exec diff ../outputs/t796 ../golden/t796 >/dev/null 2>&1 ;;
  p797) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAM.mat > ../outputs/t797
    exec diff ../outputs/t797 ../golden/t797 >/dev/null 2>&1 ;;
  p798) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAN.mat > ../outputs/t798
    exec diff ../outputs/t798 ../golden/t798 >/dev/null 2>&1 ;;
  p799) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAO.mat > ../outputs/t799
    exec diff ../outputs/t799 ../golden/t799 >/dev/null 2>&1 ;;
  p800) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAP.mat > ../outputs/t800
    exec diff ../outputs/t800 ../golden/t800 >/dev/null 2>&1 ;;
  p801) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAQ.mat > ../outputs/t801
    exec diff ../outputs/t801 ../golden/t801 >/dev/null 2>&1 ;;
  p802) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAR.mat > ../outputs/t802
    exec diff ../outputs/t802 ../golden/t802 >/dev/null 2>&1 ;;
  p803) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAS.mat > ../outputs/t803
    exec diff ../outputs/t803 ../golden/t803 >/dev/null 2>&1 ;;
  p804) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAT.mat > ../outputs/t804
    exec diff ../outputs/t804 ../golden/t804 >/dev/null 2>&1 ;;
  p805) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAU.mat > ../outputs/t805
    exec diff ../outputs/t805 ../golden/t805 >/dev/null 2>&1 ;;
  p806) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAV.mat > ../outputs/t806
    exec diff ../outputs/t806 ../golden/t806 >/dev/null 2>&1 ;;
  p807) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAW.mat > ../outputs/t807
    exec diff ../outputs/t807 ../golden/t807 >/dev/null 2>&1 ;;
  p808) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAX.mat > ../outputs/t808
    exec diff ../outputs/t808 ../golden/t808 >/dev/null 2>&1 ;;
  p809) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAY.mat > ../outputs/t809
    exec diff ../outputs/t809 ../golden/t809 >/dev/null 2>&1 ;;
  p810) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAZ.mat > ../outputs/t810
    exec diff ../outputs/t810 ../golden/t810 >/dev/null 2>&1 ;;
  p811) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAA[.mat > ../outputs/t811
    exec diff ../outputs/t811 ../golden/t811 >/dev/null 2>&1 ;;
  p812) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAA].mat > ../outputs/t812
    exec diff ../outputs/t812 ../golden/t812 >/dev/null 2>&1 ;;
  p813) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAA_.mat > ../outputs/t813
    exec diff ../outputs/t813 ../golden/t813 >/dev/null 2>&1 ;;
  p814) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAa.mat > ../outputs/t814
    exec diff ../outputs/t814 ../golden/t814 >/dev/null 2>&1 ;;
  p815) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAb.mat > ../outputs/t815
    exec diff ../outputs/t815 ../golden/t815 >/dev/null 2>&1 ;;
  p816) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAc.mat > ../outputs/t816
    exec diff ../outputs/t816 ../golden/t816 >/dev/null 2>&1 ;;
  p817) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAd.mat > ../outputs/t817
    exec diff ../outputs/t817 ../golden/t817 >/dev/null 2>&1 ;;
  p818) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAe.mat > ../outputs/t818
    exec diff ../outputs/t818 ../golden/t818 >/dev/null 2>&1 ;;
  p819) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAf.mat > ../outputs/t819
    exec diff ../outputs/t819 ../golden/t819 >/dev/null 2>&1 ;;
  p820) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAg.mat > ../outputs/t820
    exec diff ../outputs/t820 ../golden/t820 >/dev/null 2>&1 ;;
  p821) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAh.mat > ../outputs/t821
    exec diff ../outputs/t821 ../golden/t821 >/dev/null 2>&1 ;;
  p822) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAi.mat > ../outputs/t822
    exec diff ../outputs/t822 ../golden/t822 >/dev/null 2>&1 ;;
  p823) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAj.mat > ../outputs/t823
    exec diff ../outputs/t823 ../golden/t823 >/dev/null 2>&1 ;;
  p824) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAk.mat > ../outputs/t824
    exec diff ../outputs/t824 ../golden/t824 >/dev/null 2>&1 ;;
  p825) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAl.mat > ../outputs/t825
    exec diff ../outputs/t825 ../golden/t825 >/dev/null 2>&1 ;;
  p826) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAm.mat > ../outputs/t826
    exec diff ../outputs/t826 ../golden/t826 >/dev/null 2>&1 ;;
  p827) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAn.mat > ../outputs/t827
    exec diff ../outputs/t827 ../golden/t827 >/dev/null 2>&1 ;;
  p828) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAo.mat > ../outputs/t828
    exec diff ../outputs/t828 ../golden/t828 >/dev/null 2>&1 ;;
  p829) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAp.mat > ../outputs/t829
    exec diff ../outputs/t829 ../golden/t829 >/dev/null 2>&1 ;;
  p830) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAq.mat > ../outputs/t830
    exec diff ../outputs/t830 ../golden/t830 >/dev/null 2>&1 ;;
  p831) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAr.mat > ../outputs/t831
    exec diff ../outputs/t831 ../golden/t831 >/dev/null 2>&1 ;;
  p832) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAs.mat > ../outputs/t832
    exec diff ../outputs/t832 ../golden/t832 >/dev/null 2>&1 ;;
  p833) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAt.mat > ../outputs/t833
    exec diff ../outputs/t833 ../golden/t833 >/dev/null 2>&1 ;;
  p834) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAu.mat > ../outputs/t834
    exec diff ../outputs/t834 ../golden/t834 >/dev/null 2>&1 ;;
  p835) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAv.mat > ../outputs/t835
    exec diff ../outputs/t835 ../golden/t835 >/dev/null 2>&1 ;;
  p836) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAw.mat > ../outputs/t836
    exec diff ../outputs/t836 ../golden/t836 >/dev/null 2>&1 ;;
  p837) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAx.mat > ../outputs/t837
    exec diff ../outputs/t837 ../golden/t837 >/dev/null 2>&1 ;;
  p838) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkAAy.mat > ../outputs/t838
    exec diff ../outputs/t838 ../golden/t838 >/dev/null 2>&1 ;;
  p839) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABA.mat > ../outputs/t839
    exec diff ../outputs/t839 ../golden/t839 >/dev/null 2>&1 ;;
  p840) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABB.mat > ../outputs/t840
    exec diff ../outputs/t840 ../golden/t840 >/dev/null 2>&1 ;;
  p841) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABC.mat > ../outputs/t841
    exec diff ../outputs/t841 ../golden/t841 >/dev/null 2>&1 ;;
  p842) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABD.mat > ../outputs/t842
    exec diff ../outputs/t842 ../golden/t842 >/dev/null 2>&1 ;;
  p843) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABE.mat > ../outputs/t843
    exec diff ../outputs/t843 ../golden/t843 >/dev/null 2>&1 ;;
  p844) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABF.mat > ../outputs/t844
    exec diff ../outputs/t844 ../golden/t844 >/dev/null 2>&1 ;;
  p845) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABG.mat > ../outputs/t845
    exec diff ../outputs/t845 ../golden/t845 >/dev/null 2>&1 ;;
  p846) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABH.mat > ../outputs/t846
    exec diff ../outputs/t846 ../golden/t846 >/dev/null 2>&1 ;;
  p847) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABI.mat > ../outputs/t847
    exec diff ../outputs/t847 ../golden/t847 >/dev/null 2>&1 ;;
  p848) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABJ.mat > ../outputs/t848
    exec diff ../outputs/t848 ../golden/t848 >/dev/null 2>&1 ;;
  p849) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABK.mat > ../outputs/t849
    exec diff ../outputs/t849 ../golden/t849 >/dev/null 2>&1 ;;
  p850) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABL.mat > ../outputs/t850
    exec diff ../outputs/t850 ../golden/t850 >/dev/null 2>&1 ;;
  p851) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABM.mat > ../outputs/t851
    exec diff ../outputs/t851 ../golden/t851 >/dev/null 2>&1 ;;
  p852) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABN.mat > ../outputs/t852
    exec diff ../outputs/t852 ../golden/t852 >/dev/null 2>&1 ;;
  p853) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABO.mat > ../outputs/t853
    exec diff ../outputs/t853 ../golden/t853 >/dev/null 2>&1 ;;
  p854) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABP.mat > ../outputs/t854
    exec diff ../outputs/t854 ../golden/t854 >/dev/null 2>&1 ;;
  p855) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABQ.mat > ../outputs/t855
    exec diff ../outputs/t855 ../golden/t855 >/dev/null 2>&1 ;;
  p856) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABR.mat > ../outputs/t856
    exec diff ../outputs/t856 ../golden/t856 >/dev/null 2>&1 ;;
  p857) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/jkABS.mat > ../outputs/t857
    exec diff ../outputs/t857 ../golden/t857 >/dev/null 2>&1 ;;
  p858) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new1 > ../outputs/t858
    exec diff ../outputs/t858 ../golden/t858 >/dev/null 2>&1 ;;
  p859) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new10 > ../outputs/t859
    exec diff ../outputs/t859 ../golden/t859 >/dev/null 2>&1 ;;
  p860) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new11 > ../outputs/t860
    exec diff ../outputs/t860 ../golden/t860 >/dev/null 2>&1 ;;
  p861) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new12 > ../outputs/t861
    exec diff ../outputs/t861 ../golden/t861 >/dev/null 2>&1 ;;
  p862) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new13 > ../outputs/t862
    exec diff ../outputs/t862 ../golden/t862 >/dev/null 2>&1 ;;
  p863) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new14 > ../outputs/t863
    exec diff ../outputs/t863 ../golden/t863 >/dev/null 2>&1 ;;
  p864) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new15 > ../outputs/t864
    exec diff ../outputs/t864 ../golden/t864 >/dev/null 2>&1 ;;
  p865) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new16 > ../outputs/t865
    exec diff ../outputs/t865 ../golden/t865 >/dev/null 2>&1 ;;
  p866) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new17 > ../outputs/t866
    exec diff ../outputs/t866 ../golden/t866 >/dev/null 2>&1 ;;
  p867) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new18 > ../outputs/t867
    exec diff ../outputs/t867 ../golden/t867 >/dev/null 2>&1 ;;
  p868) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new19 > ../outputs/t868
    exec diff ../outputs/t868 ../golden/t868 >/dev/null 2>&1 ;;
  p869) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new2 > ../outputs/t869
    exec diff ../outputs/t869 ../golden/t869 >/dev/null 2>&1 ;;
  p870) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new20 > ../outputs/t870
    exec diff ../outputs/t870 ../golden/t870 >/dev/null 2>&1 ;;
  p871) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new21 > ../outputs/t871
    exec diff ../outputs/t871 ../golden/t871 >/dev/null 2>&1 ;;
  p872) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new22 > ../outputs/t872
    exec diff ../outputs/t872 ../golden/t872 >/dev/null 2>&1 ;;
  p873) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new23 > ../outputs/t873
    exec diff ../outputs/t873 ../golden/t873 >/dev/null 2>&1 ;;
  p874) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new24 > ../outputs/t874
    exec diff ../outputs/t874 ../golden/t874 >/dev/null 2>&1 ;;
  p875) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new25 > ../outputs/t875
    exec diff ../outputs/t875 ../golden/t875 >/dev/null 2>&1 ;;
  p876) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new26 > ../outputs/t876
    exec diff ../outputs/t876 ../golden/t876 >/dev/null 2>&1 ;;
  p877) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new27 > ../outputs/t877
    exec diff ../outputs/t877 ../golden/t877 >/dev/null 2>&1 ;;
  p878) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new28 > ../outputs/t878
    exec diff ../outputs/t878 ../golden/t878 >/dev/null 2>&1 ;;
  p879) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new29 > ../outputs/t879
    exec diff ../outputs/t879 ../golden/t879 >/dev/null 2>&1 ;;
  p880) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new3 > ../outputs/t880
    exec diff ../outputs/t880 ../golden/t880 >/dev/null 2>&1 ;;
  p881) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new30 > ../outputs/t881
    exec diff ../outputs/t881 ../golden/t881 >/dev/null 2>&1 ;;
  p882) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new31 > ../outputs/t882
    exec diff ../outputs/t882 ../golden/t882 >/dev/null 2>&1 ;;
  p883) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new32 > ../outputs/t883
    exec diff ../outputs/t883 ../golden/t883 >/dev/null 2>&1 ;;
  p884) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new33 > ../outputs/t884
    exec diff ../outputs/t884 ../golden/t884 >/dev/null 2>&1 ;;
  p885) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new34 > ../outputs/t885
    exec diff ../outputs/t885 ../golden/t885 >/dev/null 2>&1 ;;
  p886) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new35 > ../outputs/t886
    exec diff ../outputs/t886 ../golden/t886 >/dev/null 2>&1 ;;
  p887) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new36 > ../outputs/t887
    exec diff ../outputs/t887 ../golden/t887 >/dev/null 2>&1 ;;
  p888) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new37 > ../outputs/t888
    exec diff ../outputs/t888 ../golden/t888 >/dev/null 2>&1 ;;
  p889) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new38 > ../outputs/t889
    exec diff ../outputs/t889 ../golden/t889 >/dev/null 2>&1 ;;
  p890) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new39 > ../outputs/t890
    exec diff ../outputs/t890 ../golden/t890 >/dev/null 2>&1 ;;
  p891) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new4 > ../outputs/t891
    exec diff ../outputs/t891 ../golden/t891 >/dev/null 2>&1 ;;
  p892) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new40 > ../outputs/t892
    exec diff ../outputs/t892 ../golden/t892 >/dev/null 2>&1 ;;
  p893) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new5 > ../outputs/t893
    exec diff ../outputs/t893 ../golden/t893 >/dev/null 2>&1 ;;
  p894) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new6 > ../outputs/t894
    exec diff ../outputs/t894 ../golden/t894 >/dev/null 2>&1 ;;
  p895) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new7 > ../outputs/t895
    exec diff ../outputs/t895 ../golden/t895 >/dev/null 2>&1 ;;
  p896) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new8 > ../outputs/t896
    exec diff ../outputs/t896 ../golden/t896 >/dev/null 2>&1 ;;
  p897) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/new9 > ../outputs/t897
    exec diff ../outputs/t897 ../golden/t897 >/dev/null 2>&1 ;;
  p898) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest12 > ../outputs/t898
    exec diff ../outputs/t898 ../golden/t898 >/dev/null 2>&1 ;;
  p899) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest13 > ../outputs/t899
    exec diff ../outputs/t899 ../golden/t899 >/dev/null 2>&1 ;;
  p900) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest14 > ../outputs/t900
    exec diff ../outputs/t900 ../golden/t900 >/dev/null 2>&1 ;;
  p901) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest15 > ../outputs/t901
    exec diff ../outputs/t901 ../golden/t901 >/dev/null 2>&1 ;;
  p902) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest16 > ../outputs/t902
    exec diff ../outputs/t902 ../golden/t902 >/dev/null 2>&1 ;;
  p903) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest17 > ../outputs/t903
    exec diff ../outputs/t903 ../golden/t903 >/dev/null 2>&1 ;;
  p904) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest18 > ../outputs/t904
    exec diff ../outputs/t904 ../golden/t904 >/dev/null 2>&1 ;;
  p905) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest19 > ../outputs/t905
    exec diff ../outputs/t905 ../golden/t905 >/dev/null 2>&1 ;;
  p906) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest2 > ../outputs/t906
    exec diff ../outputs/t906 ../golden/t906 >/dev/null 2>&1 ;;
  p907) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest20 > ../outputs/t907
    exec diff ../outputs/t907 ../golden/t907 >/dev/null 2>&1 ;;
  p908) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest21 > ../outputs/t908
    exec diff ../outputs/t908 ../golden/t908 >/dev/null 2>&1 ;;
  p909) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest22 > ../outputs/t909
    exec diff ../outputs/t909 ../golden/t909 >/dev/null 2>&1 ;;
  p910) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest23 > ../outputs/t910
    exec diff ../outputs/t910 ../golden/t910 >/dev/null 2>&1 ;;
  p911) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest24 > ../outputs/t911
    exec diff ../outputs/t911 ../golden/t911 >/dev/null 2>&1 ;;
  p912) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest25 > ../outputs/t912
    exec diff ../outputs/t912 ../golden/t912 >/dev/null 2>&1 ;;
  p913) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest26 > ../outputs/t913
    exec diff ../outputs/t913 ../golden/t913 >/dev/null 2>&1 ;;
  p914) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest27 > ../outputs/t914
    exec diff ../outputs/t914 ../golden/t914 >/dev/null 2>&1 ;;
  p915) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest28 > ../outputs/t915
    exec diff ../outputs/t915 ../golden/t915 >/dev/null 2>&1 ;;
  p916) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest29 > ../outputs/t916
    exec diff ../outputs/t916 ../golden/t916 >/dev/null 2>&1 ;;
  p917) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest3 > ../outputs/t917
    exec diff ../outputs/t917 ../golden/t917 >/dev/null 2>&1 ;;
  p918) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest30 > ../outputs/t918
    exec diff ../outputs/t918 ../golden/t918 >/dev/null 2>&1 ;;
  p919) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest31 > ../outputs/t919
    exec diff ../outputs/t919 ../golden/t919 >/dev/null 2>&1 ;;
  p920) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest32 > ../outputs/t920
    exec diff ../outputs/t920 ../golden/t920 >/dev/null 2>&1 ;;
  p921) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest33 > ../outputs/t921
    exec diff ../outputs/t921 ../golden/t921 >/dev/null 2>&1 ;;
  p922) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest35 > ../outputs/t922
    exec diff ../outputs/t922 ../golden/t922 >/dev/null 2>&1 ;;
  p923) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest36 > ../outputs/t923
    exec diff ../outputs/t923 ../golden/t923 >/dev/null 2>&1 ;;
  p924) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest37 > ../outputs/t924
    exec diff ../outputs/t924 ../golden/t924 >/dev/null 2>&1 ;;
  p925) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest38 > ../outputs/t925
    exec diff ../outputs/t925 ../golden/t925 >/dev/null 2>&1 ;;
  p926) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest39 > ../outputs/t926
    exec diff ../outputs/t926 ../golden/t926 >/dev/null 2>&1 ;;
  p927) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest4 > ../outputs/t927
    exec diff ../outputs/t927 ../golden/t927 >/dev/null 2>&1 ;;
  p928) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest40 > ../outputs/t928
    exec diff ../outputs/t928 ../golden/t928 >/dev/null 2>&1 ;;
  p929) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest41 > ../outputs/t929
    exec diff ../outputs/t929 ../golden/t929 >/dev/null 2>&1 ;;
  p930) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest42 > ../outputs/t930
    exec diff ../outputs/t930 ../golden/t930 >/dev/null 2>&1 ;;
  p931) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest43 > ../outputs/t931
    exec diff ../outputs/t931 ../golden/t931 >/dev/null 2>&1 ;;
  p932) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest44 > ../outputs/t932
    exec diff ../outputs/t932 ../golden/t932 >/dev/null 2>&1 ;;
  p933) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest45 > ../outputs/t933
    exec diff ../outputs/t933 ../golden/t933 >/dev/null 2>&1 ;;
  p934) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest46 > ../outputs/t934
    exec diff ../outputs/t934 ../golden/t934 >/dev/null 2>&1 ;;
  p935) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest48 > ../outputs/t935
    exec diff ../outputs/t935 ../golden/t935 >/dev/null 2>&1 ;;
  p936) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest49 > ../outputs/t936
    exec diff ../outputs/t936 ../golden/t936 >/dev/null 2>&1 ;;
  p937) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest5 > ../outputs/t937
    exec diff ../outputs/t937 ../golden/t937 >/dev/null 2>&1 ;;
  p938) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest50 > ../outputs/t938
    exec diff ../outputs/t938 ../golden/t938 >/dev/null 2>&1 ;;
  p939) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest51 > ../outputs/t939
    exec diff ../outputs/t939 ../golden/t939 >/dev/null 2>&1 ;;
  p940) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest52 > ../outputs/t940
    exec diff ../outputs/t940 ../golden/t940 >/dev/null 2>&1 ;;
  p941) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest53 > ../outputs/t941
    exec diff ../outputs/t941 ../golden/t941 >/dev/null 2>&1 ;;
  p942) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest54 > ../outputs/t942
    exec diff ../outputs/t942 ../golden/t942 >/dev/null 2>&1 ;;
  p943) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest55 > ../outputs/t943
    exec diff ../outputs/t943 ../golden/t943 >/dev/null 2>&1 ;;
  p944) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest56 > ../outputs/t944
    exec diff ../outputs/t944 ../golden/t944 >/dev/null 2>&1 ;;
  p945) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest57 > ../outputs/t945
    exec diff ../outputs/t945 ../golden/t945 >/dev/null 2>&1 ;;
  p946) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest6 > ../outputs/t946
    exec diff ../outputs/t946 ../golden/t946 >/dev/null 2>&1 ;;
  p947) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest7 > ../outputs/t947
    exec diff ../outputs/t947 ../golden/t947 >/dev/null 2>&1 ;;
  p948) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/ntest9 > ../outputs/t948
    exec diff ../outputs/t948 ../golden/t948 >/dev/null 2>&1 ;;
  p949) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew1 > ../outputs/t949
    exec diff ../outputs/t949 ../golden/t949 >/dev/null 2>&1 ;;
  p950) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew10 > ../outputs/t950
    exec diff ../outputs/t950 ../golden/t950 >/dev/null 2>&1 ;;
  p951) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew11 > ../outputs/t951
    exec diff ../outputs/t951 ../golden/t951 >/dev/null 2>&1 ;;
  p952) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew12 > ../outputs/t952
    exec diff ../outputs/t952 ../golden/t952 >/dev/null 2>&1 ;;
  p953) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew13 > ../outputs/t953
    exec diff ../outputs/t953 ../golden/t953 >/dev/null 2>&1 ;;
  p954) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew14 > ../outputs/t954
    exec diff ../outputs/t954 ../golden/t954 >/dev/null 2>&1 ;;
  p955) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew15 > ../outputs/t955
    exec diff ../outputs/t955 ../golden/t955 >/dev/null 2>&1 ;;
  p956) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew16 > ../outputs/t956
    exec diff ../outputs/t956 ../golden/t956 >/dev/null 2>&1 ;;
  p957) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew17 > ../outputs/t957
    exec diff ../outputs/t957 ../golden/t957 >/dev/null 2>&1 ;;
  p958) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew18 > ../outputs/t958
    exec diff ../outputs/t958 ../golden/t958 >/dev/null 2>&1 ;;
  p959) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew19 > ../outputs/t959
    exec diff ../outputs/t959 ../golden/t959 >/dev/null 2>&1 ;;
  p960) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew2 > ../outputs/t960
    exec diff ../outputs/t960 ../golden/t960 >/dev/null 2>&1 ;;
  p961) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew20 > ../outputs/t961
    exec diff ../outputs/t961 ../golden/t961 >/dev/null 2>&1 ;;
  p962) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew21 > ../outputs/t962
    exec diff ../outputs/t962 ../golden/t962 >/dev/null 2>&1 ;;
  p963) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew22 > ../outputs/t963
    exec diff ../outputs/t963 ../golden/t963 >/dev/null 2>&1 ;;
  p964) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew23 > ../outputs/t964
    exec diff ../outputs/t964 ../golden/t964 >/dev/null 2>&1 ;;
  p965) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew24 > ../outputs/t965
    exec diff ../outputs/t965 ../golden/t965 >/dev/null 2>&1 ;;
  p966) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew25 > ../outputs/t966
    exec diff ../outputs/t966 ../golden/t966 >/dev/null 2>&1 ;;
  p967) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew26 > ../outputs/t967
    exec diff ../outputs/t967 ../golden/t967 >/dev/null 2>&1 ;;
  p968) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew27 > ../outputs/t968
    exec diff ../outputs/t968 ../golden/t968 >/dev/null 2>&1 ;;
  p969) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew3 > ../outputs/t969
    exec diff ../outputs/t969 ../golden/t969 >/dev/null 2>&1 ;;
  p970) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew4 > ../outputs/t970
    exec diff ../outputs/t970 ../golden/t970 >/dev/null 2>&1 ;;
  p971) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew5 > ../outputs/t971
    exec diff ../outputs/t971 ../golden/t971 >/dev/null 2>&1 ;;
  p972) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew6 > ../outputs/t972
    exec diff ../outputs/t972 ../golden/t972 >/dev/null 2>&1 ;;
  p973) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew7 > ../outputs/t973
    exec diff ../outputs/t973 ../golden/t973 >/dev/null 2>&1 ;;
  p974) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew8 > ../outputs/t974
    exec diff ../outputs/t974 ../golden/t974 >/dev/null 2>&1 ;;
  p975) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnew9 > ../outputs/t975
    exec diff ../outputs/t975 ../golden/t975 >/dev/null 2>&1 ;;
  p976) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt1 > ../outputs/t976
    exec diff ../outputs/t976 ../golden/t976 >/dev/null 2>&1 ;;
  p977) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt10 > ../outputs/t977
    exec diff ../outputs/t977 ../golden/t977 >/dev/null 2>&1 ;;
  p978) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt11 > ../outputs/t978
    exec diff ../outputs/t978 ../golden/t978 >/dev/null 2>&1 ;;
  p979) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt12 > ../outputs/t979
    exec diff ../outputs/t979 ../golden/t979 >/dev/null 2>&1 ;;
  p980) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt13 > ../outputs/t980
    exec diff ../outputs/t980 ../golden/t980 >/dev/null 2>&1 ;;
  p981) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt14 > ../outputs/t981
    exec diff ../outputs/t981 ../golden/t981 >/dev/null 2>&1 ;;
  p982) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt15 > ../outputs/t982
    exec diff ../outputs/t982 ../golden/t982 >/dev/null 2>&1 ;;
  p983) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt16 > ../outputs/t983
    exec diff ../outputs/t983 ../golden/t983 >/dev/null 2>&1 ;;
  p984) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt2 > ../outputs/t984
    exec diff ../outputs/t984 ../golden/t984 >/dev/null 2>&1 ;;
  p985) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt3 > ../outputs/t985
    exec diff ../outputs/t985 ../golden/t985 >/dev/null 2>&1 ;;
  p986) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt4 > ../outputs/t986
    exec diff ../outputs/t986 ../golden/t986 >/dev/null 2>&1 ;;
  p987) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt5 > ../outputs/t987
    exec diff ../outputs/t987 ../golden/t987 >/dev/null 2>&1 ;;
  p988) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt6 > ../outputs/t988
    exec diff ../outputs/t988 ../golden/t988 >/dev/null 2>&1 ;;
  p989) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt7 > ../outputs/t989
    exec diff ../outputs/t989 ../golden/t989 >/dev/null 2>&1 ;;
  p990) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt8 > ../outputs/t990
    exec diff ../outputs/t990 ../golden/t990 >/dev/null 2>&1 ;;
  p991) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/bnewt9 > ../outputs/t991
    exec diff ../outputs/t991 ../golden/t991 >/dev/null 2>&1 ;;
  p992) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new1 > ../outputs/t992
    exec diff ../outputs/t992 ../golden/t992 >/dev/null 2>&1 ;;
  p993) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new10 > ../outputs/t993
    exec diff ../outputs/t993 ../golden/t993 >/dev/null 2>&1 ;;
  p994) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new11 > ../outputs/t994
    exec diff ../outputs/t994 ../golden/t994 >/dev/null 2>&1 ;;
  p995) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new12 > ../outputs/t995
    exec diff ../outputs/t995 ../golden/t995 >/dev/null 2>&1 ;;
  p996) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new13 > ../outputs/t996
    exec diff ../outputs/t996 ../golden/t996 >/dev/null 2>&1 ;;
  p997) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new14 > ../outputs/t997
    exec diff ../outputs/t997 ../golden/t997 >/dev/null 2>&1 ;;
  p998) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new15 > ../outputs/t998
    exec diff ../outputs/t998 ../golden/t998 >/dev/null 2>&1 ;;
  p999) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new16 > ../outputs/t999
    exec diff ../outputs/t999 ../golden/t999 >/dev/null 2>&1 ;;
  p1000) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new17 > ../outputs/t1000
    exec diff ../outputs/t1000 ../golden/t1000 >/dev/null 2>&1 ;;
  p1001) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new18 > ../outputs/t1001
    exec diff ../outputs/t1001 ../golden/t1001 >/dev/null 2>&1 ;;
  p1002) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new19 > ../outputs/t1002
    exec diff ../outputs/t1002 ../golden/t1002 >/dev/null 2>&1 ;;
  p1003) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new2 > ../outputs/t1003
    exec diff ../outputs/t1003 ../golden/t1003 >/dev/null 2>&1 ;;
  p1004) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new20 > ../outputs/t1004
    exec diff ../outputs/t1004 ../golden/t1004 >/dev/null 2>&1 ;;
  p1005) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new21 > ../outputs/t1005
    exec diff ../outputs/t1005 ../golden/t1005 >/dev/null 2>&1 ;;
  p1006) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new22 > ../outputs/t1006
    exec diff ../outputs/t1006 ../golden/t1006 >/dev/null 2>&1 ;;
  p1007) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new23 > ../outputs/t1007
    exec diff ../outputs/t1007 ../golden/t1007 >/dev/null 2>&1 ;;
  p1008) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new24 > ../outputs/t1008
    exec diff ../outputs/t1008 ../golden/t1008 >/dev/null 2>&1 ;;
  p1009) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new25 > ../outputs/t1009
    exec diff ../outputs/t1009 ../golden/t1009 >/dev/null 2>&1 ;;
  p1010) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new26 > ../outputs/t1010
    exec diff ../outputs/t1010 ../golden/t1010 >/dev/null 2>&1 ;;
  p1011) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new27 > ../outputs/t1011
    exec diff ../outputs/t1011 ../golden/t1011 >/dev/null 2>&1 ;;
  p1012) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new28 > ../outputs/t1012
    exec diff ../outputs/t1012 ../golden/t1012 >/dev/null 2>&1 ;;
  p1013) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new29 > ../outputs/t1013
    exec diff ../outputs/t1013 ../golden/t1013 >/dev/null 2>&1 ;;
  p1014) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new3 > ../outputs/t1014
    exec diff ../outputs/t1014 ../golden/t1014 >/dev/null 2>&1 ;;
  p1015) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new30 > ../outputs/t1015
    exec diff ../outputs/t1015 ../golden/t1015 >/dev/null 2>&1 ;;
  p1016) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new31 > ../outputs/t1016
    exec diff ../outputs/t1016 ../golden/t1016 >/dev/null 2>&1 ;;
  p1017) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new32 > ../outputs/t1017
    exec diff ../outputs/t1017 ../golden/t1017 >/dev/null 2>&1 ;;
  p1018) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new33 > ../outputs/t1018
    exec diff ../outputs/t1018 ../golden/t1018 >/dev/null 2>&1 ;;
  p1019) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new34 > ../outputs/t1019
    exec diff ../outputs/t1019 ../golden/t1019 >/dev/null 2>&1 ;;
  p1020) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new35 > ../outputs/t1020
    exec diff ../outputs/t1020 ../golden/t1020 >/dev/null 2>&1 ;;
  p1021) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new36 > ../outputs/t1021
    exec diff ../outputs/t1021 ../golden/t1021 >/dev/null 2>&1 ;;
  p1022) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new37 > ../outputs/t1022
    exec diff ../outputs/t1022 ../golden/t1022 >/dev/null 2>&1 ;;
  p1023) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new38 > ../outputs/t1023
    exec diff ../outputs/t1023 ../golden/t1023 >/dev/null 2>&1 ;;
  p1024) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new39 > ../outputs/t1024
    exec diff ../outputs/t1024 ../golden/t1024 >/dev/null 2>&1 ;;
  p1025) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new4 > ../outputs/t1025
    exec diff ../outputs/t1025 ../golden/t1025 >/dev/null 2>&1 ;;
  p1026) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new40 > ../outputs/t1026
    exec diff ../outputs/t1026 ../golden/t1026 >/dev/null 2>&1 ;;
  p1027) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new5 > ../outputs/t1027
    exec diff ../outputs/t1027 ../golden/t1027 >/dev/null 2>&1 ;;
  p1028) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new6 > ../outputs/t1028
    exec diff ../outputs/t1028 ../golden/t1028 >/dev/null 2>&1 ;;
  p1029) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new7 > ../outputs/t1029
    exec diff ../outputs/t1029 ../golden/t1029 >/dev/null 2>&1 ;;
  p1030) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new8 > ../outputs/t1030
    exec diff ../outputs/t1030 ../golden/t1030 >/dev/null 2>&1 ;;
  p1031) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new9 > ../outputs/t1031
    exec diff ../outputs/t1031 ../golden/t1031 >/dev/null 2>&1 ;;
  p1032) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new40 > ../outputs/t1032
    exec diff ../outputs/t1032 ../golden/t1032 >/dev/null 2>&1 ;;
  p1033) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new41 > ../outputs/t1033
    exec diff ../outputs/t1033 ../golden/t1033 >/dev/null 2>&1 ;;
  p1034) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new42 > ../outputs/t1034
    exec diff ../outputs/t1034 ../golden/t1034 >/dev/null 2>&1 ;;
  p1035) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new43 > ../outputs/t1035
    exec diff ../outputs/t1035 ../golden/t1035 >/dev/null 2>&1 ;;
  p1036) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new44 > ../outputs/t1036
    exec diff ../outputs/t1036 ../golden/t1036 >/dev/null 2>&1 ;;
  p1037) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new45 > ../outputs/t1037
    exec diff ../outputs/t1037 ../golden/t1037 >/dev/null 2>&1 ;;
  p1038) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new46 > ../outputs/t1038
    exec diff ../outputs/t1038 ../golden/t1038 >/dev/null 2>&1 ;;
  p1039) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new47 > ../outputs/t1039
    exec diff ../outputs/t1039 ../golden/t1039 >/dev/null 2>&1 ;;
  p1040) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new48 > ../outputs/t1040
    exec diff ../outputs/t1040 ../golden/t1040 >/dev/null 2>&1 ;;
  p1041) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new49 > ../outputs/t1041
    exec diff ../outputs/t1041 ../golden/t1041 >/dev/null 2>&1 ;;
  p1042) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new50 > ../outputs/t1042
    exec diff ../outputs/t1042 ../golden/t1042 >/dev/null 2>&1 ;;
  p1043) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new51 > ../outputs/t1043
    exec diff ../outputs/t1043 ../golden/t1043 >/dev/null 2>&1 ;;
  p1044) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new52 > ../outputs/t1044
    exec diff ../outputs/t1044 ../golden/t1044 >/dev/null 2>&1 ;;
  p1045) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new53 > ../outputs/t1045
    exec diff ../outputs/t1045 ../golden/t1045 >/dev/null 2>&1 ;;
  p1046) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new54 > ../outputs/t1046
    exec diff ../outputs/t1046 ../golden/t1046 >/dev/null 2>&1 ;;
  p1047) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new55 > ../outputs/t1047
    exec diff ../outputs/t1047 ../golden/t1047 >/dev/null 2>&1 ;;
  p1048) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new56 > ../outputs/t1048
    exec diff ../outputs/t1048 ../golden/t1048 >/dev/null 2>&1 ;;
  p1049) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new57 > ../outputs/t1049
    exec diff ../outputs/t1049 ../golden/t1049 >/dev/null 2>&1 ;;
  p1050) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new58 > ../outputs/t1050
    exec diff ../outputs/t1050 ../golden/t1050 >/dev/null 2>&1 ;;
  p1051) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new59 > ../outputs/t1051
    exec diff ../outputs/t1051 ../golden/t1051 >/dev/null 2>&1 ;;
  p1052) timeout -s 9 2 ../source/tot_info.exe  < ../inputs/universe/12new60 > ../outputs/t1052
    exec diff ../outputs/t1052 ../golden/t1052 >/dev/null 2>&1 ;;
  *) exit 2 ;;
esac
